@@ -4,7 +4,7 @@ use nu_engine::CallExt;
 use nu_protocol::{
     ast::Call,
     engine::{Command, EngineState, Stack},
-    Category, Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    Category, Example, PipelineData, Record, ShellError, Signature, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -41,20 +41,18 @@ impl Command for ExprAlias {
                 let cols = vec!["expr".into(), "value".into()];
                 let expr = Value::test_string("column");
                 let value = Value::test_string("a");
-                let expr = Value::Record {
+                let expr = Value::test_record(Record {
                     cols,
                     vals: vec![expr, value],
-                    span: Span::test_data(),
-                };
+                });
 
                 let cols = vec!["expr".into(), "alias".into()];
                 let value = Value::test_string("new_a");
 
-                let record = Value::Record {
+                let record = Value::test_record(Record {
                     cols,
                     vals: vec![expr, value],
-                    span: Span::test_data(),
-                };
+                });
 
                 Some(record)
             },
