@@ -71,58 +71,51 @@ impl Command for BitsInto {
             Example {
                 description: "convert a binary value into a string, padded to 8 places with 0s",
                 example: "01b | into bits",
-                result: Some(Value::String {
-                    val: "00000001".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("00000001",
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert an int into a string, padded to 8 places with 0s",
                 example: "1 | into bits",
-                result: Some(Value::String {
-                    val: "00000001".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("00000001",
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a filesize value into a string, padded to 8 places with 0s",
                 example: "1b | into bits",
-                result: Some(Value::String {
-                    val: "00000001".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("00000001",
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a duration value into a string, padded to 8 places with 0s",
                 example: "1ns | into bits",
-                result: Some(Value::String {
-                    val: "00000001".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("00000001",
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a boolean value into a string, padded to 8 places with 0s",
                 example: "true | into bits",
-                result: Some(Value::String {
-                    val: "00000001".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("00000001",
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a datetime value into a string, padded to 8 places with 0s",
                 example: "2023-04-17T01:02:03 | into bits",
-                result: Some(Value::String {
-                    val: "01001101 01101111 01101110 00100000 01000001 01110000 01110010 00100000 00110001 00110111 00100000 00110000 00110001 00111010 00110000 00110010 00111010 00110000 00110011 00100000 00110010 00110000 00110010 00110011".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("01001101 01101111 01101110 00100000 01000001 01110000 01110010 00100000 00110001 00110111 00100000 00110000 00110001 00111010 00110000 00110010 00111010 00110000 00110011 00100000 00110010 00110000 00110010 00110011",
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a string into a raw binary string, padded with 0s to 8 places",
                 example: "'nushell.sh' | into bits",
-                result: Some(Value::String {
-                    val: "01101110 01110101 01110011 01101000 01100101 01101100 01101100 00101110 01110011 01101000".to_string(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("01101110 01110101 01110011 01101000 01100101 01101100 01101100 00101110 01110011 01101000",
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -139,22 +132,16 @@ fn into_bits(
     let cell_paths = (!cell_paths.is_empty()).then_some(cell_paths);
 
     match input {
-        PipelineData::ExternalStream { stdout: None, .. } => Ok(Value::Binary {
-            val: vec![],
-            span: head,
+        PipelineData::ExternalStream { stdout: None, .. } => {
+            Ok(Value::binary(vec![], head).into_pipeline_data())
         }
-        .into_pipeline_data()),
         PipelineData::ExternalStream {
             stdout: Some(stream),
             ..
         } => {
             // TODO: in the future, we may want this to stream out, converting each to bytes
             let output = stream.into_bytes()?;
-            Ok(Value::Binary {
-                val: output.item,
-                span: head,
-            }
-            .into_pipeline_data())
+            Ok(Value::binary(output.item, head).into_pipeline_data())
         }
         _ => {
             let args = Arguments { cell_paths };
@@ -170,40 +157,28 @@ fn convert_to_smallest_number_type(num: i64, span: Span) -> Value {
         for ch in bytes {
             raw_string.push_str(&format!("{:08b} ", ch));
         }
-        Value::String {
-            val: raw_string.trim().to_string(),
-            span,
-        }
+        Value::string(raw_string.trim(), span)
     } else if let Some(v) = num.to_i16() {
         let bytes = v.to_ne_bytes();
         let mut raw_string = "".to_string();
         for ch in bytes {
             raw_string.push_str(&format!("{:08b} ", ch));
         }
-        Value::String {
-            val: raw_string.trim().to_string(),
-            span,
-        }
+        Value::string(raw_string.trim(), span)
     } else if let Some(v) = num.to_i32() {
         let bytes = v.to_ne_bytes();
         let mut raw_string = "".to_string();
         for ch in bytes {
             raw_string.push_str(&format!("{:08b} ", ch));
         }
-        Value::String {
-            val: raw_string.trim().to_string(),
-            span,
-        }
+        Value::string(raw_string.trim(), span)
     } else {
         let bytes = num.to_ne_bytes();
         let mut raw_string = "".to_string();
         for ch in bytes {
             raw_string.push_str(&format!("{:08b} ", ch));
         }
-        Value::String {
-            val: raw_string.trim().to_string(),
-            span,
-        }
+        Value::string(raw_string.trim(), span)
     }
 }
 
@@ -214,10 +189,7 @@ pub fn action(input: &Value, _args: &Arguments, span: Span) -> Value {
             for ch in val {
                 raw_string.push_str(&format!("{:08b} ", ch));
             }
-            Value::String {
-                val: raw_string.trim().to_string(),
-                span,
-            }
+            Value::string(raw_string.trim(), span)
         }
         Value::Int { val, .. } => convert_to_smallest_number_type(*val, span),
         Value::Filesize { val, .. } => convert_to_smallest_number_type(*val, span),
@@ -228,10 +200,7 @@ pub fn action(input: &Value, _args: &Arguments, span: Span) -> Value {
             for ch in raw_bytes {
                 raw_string.push_str(&format!("{:08b} ", ch));
             }
-            Value::String {
-                val: raw_string.trim().to_string(),
-                span,
-            }
+            Value::string(raw_string.trim(), span)
         }
         Value::Bool { val, .. } => {
             let v = <i64 as From<bool>>::from(*val);
@@ -244,21 +213,19 @@ pub fn action(input: &Value, _args: &Arguments, span: Span) -> Value {
             for ch in bytes {
                 raw_string.push_str(&format!("{:08b} ", ch));
             }
-            Value::String {
-                val: raw_string.trim().to_string(),
-                span,
-            }
+            Value::string(raw_string.trim(), span)
         }
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => input.clone(),
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "integer, filesize, string, date, duration, binary or bool".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: span,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            span,
+        ),
     }
 }
 
