@@ -2,8 +2,8 @@ use nu_engine::CallExt;
 use nu_protocol::{
     ast::Call,
     engine::{Command, EngineState, Stack},
-    Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span, SyntaxShape,
-    Type, Value,
+    Category, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span,
+    SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -38,28 +38,25 @@ impl Command for Rotate {
             Example {
                 description: "Rotate a record clockwise, producing a table (like `transpose` but with column order reversed)",
                 example: "{a:1, b:2} | rotate",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(vec![
+                        Value::test_record(Record {
                             cols: vec!["column0".to_string(), "column1".to_string()],
                             vals: vec![Value::test_int(1), Value::test_string("a")],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec!["column0".to_string(), "column1".to_string()],
                             vals: vec![Value::test_int(2), Value::test_string("b")],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Rotate 2x3 table clockwise",
                 example: "[[a b]; [1 2] [3 4] [5 6]] | rotate",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec![
                                 "column0".to_string(),
                                 "column1".to_string(),
@@ -72,9 +69,8 @@ impl Command for Rotate {
                                 Value::test_int(1),
                                 Value::test_string("a"),
                             ],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec![
                                 "column0".to_string(),
                                 "column1".to_string(),
@@ -87,56 +83,51 @@ impl Command for Rotate {
                                 Value::test_int(2),
                                 Value::test_string("b"),
                             ],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Rotate table clockwise and change columns names",
                 example: "[[a b]; [1 2]] | rotate col_a col_b",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec!["col_a".to_string(), "col_b".to_string()],
                             vals: vec![Value::test_int(1), Value::test_string("a")],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec!["col_a".to_string(), "col_b".to_string()],
                             vals: vec![Value::test_int(2), Value::test_string("b")],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Rotate table counter clockwise",
                 example: "[[a b]; [1 2]] | rotate --ccw",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec!["column0".to_string(), "column1".to_string()],
                             vals: vec![Value::test_string("b"), Value::test_int(2)],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec!["column0".to_string(), "column1".to_string()],
                             vals: vec![Value::test_string("a"), Value::test_int(1)],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Rotate table counter-clockwise",
                 example: "[[a b]; [1 2] [3 4] [5 6]] | rotate --ccw",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec![
                                 "column0".to_string(),
                                 "column1".to_string(),
@@ -149,9 +140,8 @@ impl Command for Rotate {
                                 Value::test_int(4),
                                 Value::test_int(6),
                             ],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec![
                                 "column0".to_string(),
                                 "column1".to_string(),
@@ -164,30 +154,27 @@ impl Command for Rotate {
                                 Value::test_int(3),
                                 Value::test_int(5),
                             ],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Rotate table counter-clockwise and change columns names",
                 example: "[[a b]; [1 2]] | rotate --ccw col_a col_b",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec!["col_a".to_string(), "col_b".to_string()],
                             vals: vec![Value::test_string("b"), Value::test_int(2)],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec!["col_a".to_string(), "col_b".to_string()],
                             vals: vec![Value::test_string("a"), Value::test_int(1)],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -225,10 +212,11 @@ pub fn rotate(
 
     if !values.is_empty() {
         for val in values.into_iter() {
+            let span = val.span();
             match val {
-                Value::Record { cols, vals, .. } => {
-                    old_column_names = cols;
-                    for v in vals {
+                Value::Record { val: record, .. } => {
+                    old_column_names = record.cols;
+                    for v in record.vals {
                         new_values.push(v)
                     }
                 }
@@ -238,9 +226,9 @@ pub fn rotate(
                         new_values.push(v);
                     }
                 }
-                Value::String { val, span } => {
+                Value::String { val, .. } => {
                     not_a_record = true;
-                    new_values.push(Value::String { val, span })
+                    new_values.push(Value::string(val, span))
                 }
                 x => {
                     not_a_record = true;
@@ -285,14 +273,16 @@ pub fn rotate(
     }
 
     if not_a_record {
-        return Ok(Value::List {
-            vals: vec![Value::Record {
-                cols: new_column_names,
-                vals: new_values,
-                span: call.head,
-            }],
-            span: call.head,
-        }
+        return Ok(Value::list(
+            vec![Value::record(
+                Record {
+                    cols: new_column_names,
+                    vals: new_values,
+                },
+                call.head,
+            )],
+            call.head,
+        )
         .into_pipeline_data()
         .set_metadata(metadata));
     }
@@ -333,19 +323,18 @@ pub fn rotate(
             }
             res.to_vec()
         };
-        final_values.push(Value::Record {
-            cols: new_column_names.clone(),
-            vals: new_vals,
-            span: call.head,
-        })
+        final_values.push(Value::record(
+            Record {
+                cols: new_column_names.clone(),
+                vals: new_vals,
+            },
+            call.head,
+        ))
     }
 
-    Ok(Value::List {
-        vals: final_values,
-        span: call.head,
-    }
-    .into_pipeline_data()
-    .set_metadata(metadata))
+    Ok(Value::list(final_values, call.head)
+        .into_pipeline_data()
+        .set_metadata(metadata))
 }
 
 #[cfg(test)]
