@@ -70,9 +70,10 @@ impl Command for SubCommand {
 fn operate(value: Value, head: Span, use_degrees: bool) -> Value {
     match value {
         numeric @ (Value::Int { .. } | Value::Float { .. }) => {
+            let span = numeric.span();
             let (val, span) = match numeric {
-                Value::Int { val, span } => (val as f64, span),
-                Value::Float { val, span } => (val, span),
+                Value::Int { val, .. } => (val as f64, span),
+                Value::Float { val, .. } => (val, span),
                 _ => unreachable!(),
             };
 
@@ -80,27 +81,29 @@ fn operate(value: Value, head: Span, use_degrees: bool) -> Value {
                 let val = val.acos();
                 let val = if use_degrees { val.to_degrees() } else { val };
 
-                Value::Float { val, span }
+                Value::float(val, span)
             } else {
-                Value::Error {
-                    error: Box::new(ShellError::UnsupportedInput(
+                Value::error(
+                    ShellError::UnsupportedInput(
                         "'arccos' undefined for values outside the closed interval [-1, 1].".into(),
                         "value originates from here".into(),
                         head,
                         span,
-                    )),
-                }
+                    ),
+                    span,
+                )
             }
         }
         Value::Error { .. } => value,
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "numeric".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: head,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            head,
+        ),
     }
 }
 
