@@ -2,7 +2,7 @@ use inflector::cases::pascalcase::to_pascal_case;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    Category, Example, PipelineData, Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
 
 use super::operate;
@@ -73,14 +73,13 @@ impl Command for SubCommand {
             Example {
                 description: "convert a column from a table to PascalCase",
                 example: r#"[[lang, gems]; [nu_test, 100]] | str pascal-case lang"#,
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
-                        span: Span::test_data(),
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
                         cols: vec!["lang".to_string(), "gems".to_string()],
                         vals: vec![Value::test_string("NuTest"), Value::test_int(100)],
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                    Span::test_data(),
+                )),
             },
         ]
     }
