@@ -91,55 +91,50 @@ impl Command for BytesAdd {
             Example {
                 description: "Add bytes `0x[AA]` to `0x[1F FF AA AA]`",
                 example: "0x[1F FF AA AA] | bytes add 0x[AA]",
-                result: Some(Value::Binary {
-                    val: vec![0xAA, 0x1F, 0xFF, 0xAA, 0xAA],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(vec![0xAA, 0x1F, 0xFF, 0xAA, 0xAA],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Add bytes `0x[AA BB]` to `0x[1F FF AA AA]` at index 1",
                 example: "0x[1F FF AA AA] | bytes add 0x[AA BB] -i 1",
-                result: Some(Value::Binary {
-                    val: vec![0x1F, 0xAA, 0xBB, 0xFF, 0xAA, 0xAA],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(vec![0x1F, 0xAA, 0xBB, 0xFF, 0xAA, 0xAA],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Add bytes `0x[11]` to `0x[FF AA AA]` at the end",
                 example: "0x[FF AA AA] | bytes add 0x[11] -e",
-                result: Some(Value::Binary {
-                    val: vec![0xFF, 0xAA, 0xAA, 0x11],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(vec![0xFF, 0xAA, 0xAA, 0x11],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Add bytes `0x[11 22 33]` to `0x[FF AA AA]` at the end, at index 1(the index is start from end)",
                 example: "0x[FF AA BB] | bytes add 0x[11 22 33] -e -i 1",
-                result: Some(Value::Binary {
-                    val: vec![0xFF, 0xAA, 0x11, 0x22, 0x33, 0xBB],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(vec![0xFF, 0xAA, 0x11, 0x22, 0x33, 0xBB],
+                    Span::test_data(),
+                )),
             },
         ]
     }
 }
 
 fn add(val: &Value, args: &Arguments, span: Span) -> Value {
+    let val_span = val.span();
     match val {
-        Value::Binary {
-            val,
-            span: val_span,
-        } => add_impl(val, args, *val_span),
+        Value::Binary { val, .. } => add_impl(val, args, val_span),
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => val.clone(),
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "binary".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: span,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            span,
+        ),
     }
 }
 
@@ -150,12 +145,12 @@ fn add_impl(input: &[u8], args: &Arguments, span: Span) -> Value {
                 let mut added_data = args.added_data.clone();
                 let mut result = input.to_vec();
                 result.append(&mut added_data);
-                Value::Binary { val: result, span }
+                Value::binary(result, span)
             } else {
                 let mut result = args.added_data.clone();
                 let mut input = input.to_vec();
                 result.append(&mut input);
-                Value::Binary { val: result, span }
+                Value::binary(result, span)
             }
         }
         Some(mut indx) => {
@@ -174,7 +169,7 @@ fn add_impl(input: &[u8], args: &Arguments, span: Span) -> Value {
             result.append(&mut added_data);
             let mut after_data = input[inserted_index..].to_vec();
             result.append(&mut after_data);
-            Value::Binary { val: result, span }
+            Value::binary(result, span)
         }
     }
 }
