@@ -4,11 +4,10 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span, Spanned,
-    SyntaxShape, Type, Value,
+    Category, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span,
+    Spanned, SyntaxShape, Type, Value,
 };
 use std::collections::HashMap;
-use std::iter;
 
 #[derive(Clone)]
 pub struct Histogram;
@@ -52,8 +51,8 @@ impl Command for Histogram {
             Example {
                 description: "Compute a histogram for a list of numbers",
                 example: "[1 2 1] | histogram",
-                result: Some(Value::List {
-                        vals: vec![Value::Record {
+                result: Some(Value::list (
+                        vec![Value::test_record(Record {
                             cols: vec!["value".to_string(), "count".to_string(), "quantile".to_string(), "percentage".to_string(), "frequency".to_string()],
                             vals: vec![
                                 Value::test_int(1),
@@ -62,9 +61,8 @@ impl Command for Histogram {
                                 Value::test_string("66.67%"),
                                 Value::test_string("******************************************************************"),
                             ],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec!["value".to_string(), "count".to_string(), "quantile".to_string(), "percentage".to_string(), "frequency".to_string()],
                             vals: vec![
                                 Value::test_int(2),
@@ -73,10 +71,9 @@ impl Command for Histogram {
                                 Value::test_string("33.33%"),
                                 Value::test_string("*********************************"),
                             ],
-                            span: Span::test_data(),
-                        }],
-                        span: Span::test_data(),
-                    }
+                        })],
+                        Span::test_data(),
+                    )
                  ),
             },
             Example {
@@ -145,7 +142,7 @@ impl Command for Histogram {
             calc_method,
             span,
             // Note that as_list() filters out Value::Error here.
-            data_as_value.expect_span(),
+            data_as_value.span(),
         )
     }
 }
@@ -167,10 +164,10 @@ fn run_histogram(
             for v in values {
                 match v {
                     // Propagate existing errors.
-                    Value::Error { error } => return Err(*error),
+                    Value::Error { error, .. } => return Err(*error),
                     _ => {
                         let t = v.get_type();
-                        let span = v.expect_span();
+                        let span = v.span();
                         inputs.push(HashableValue::from_value(v, head_span).map_err(|_| {
                         ShellError::UnsupportedInput(
                             "Since --column-name was not provided, only lists of hashable values are supported.".to_string(),
@@ -195,8 +192,8 @@ fn run_histogram(
             for v in values {
                 match v {
                     // parse record, and fill valid value to actual input.
-                    Value::Record { cols, vals, .. } => {
-                        for (c, v) in iter::zip(cols, vals) {
+                    Value::Record { val, .. } => {
+                        for (c, v) in val {
                             if &c == col_name {
                                 if let Ok(v) = HashableValue::from_value(v, head_span) {
                                     inputs.push(v);
@@ -205,7 +202,7 @@ fn run_histogram(
                         }
                     }
                     // Propagate existing errors.
-                    Value::Error { error } => return Err(*error),
+                    Value::Error { error, .. } => return Err(*error),
                     _ => continue,
                 }
             }
@@ -272,31 +269,23 @@ fn histogram_impl(
 
         result.push((
             count, // attach count first for easily sorting.
-            Value::Record {
-                cols: result_cols.clone(),
-                vals: vec![
-                    val.into_value(),
-                    Value::Int { val: count, span },
-                    Value::Float {
-                        val: quantile,
-                        span,
-                    },
-                    Value::String {
-                        val: percentage,
-                        span,
-                    },
-                    Value::String { val: freq, span },
-                ],
+            Value::record(
+                Record {
+                    cols: result_cols.clone(),
+                    vals: vec![
+                        val.into_value(),
+                        Value::int(count, span),
+                        Value::float(quantile, span),
+                        Value::string(percentage, span),
+                        Value::string(freq, span),
+                    ],
+                },
                 span,
-            },
+            ),
         ));
     }
     result.sort_by(|a, b| b.0.cmp(&a.0));
-    Value::List {
-        vals: result.into_iter().map(|x| x.1).collect(),
-        span,
-    }
-    .into_pipeline_data()
+    Value::list(result.into_iter().map(|x| x.1).collect(), span).into_pipeline_data()
 }
 
 #[cfg(test)]
