@@ -86,53 +86,35 @@ impl Command for Fill {
                 description:
                     "Fill a string on the left side to a width of 15 with the character '─'",
                 example: "'nushell' | fill -a l -c '─' -w 15",
-                result: Some(Value::String {
-                    val: "nushell────────".into(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("nushell────────", Span::test_data())),
             },
             Example {
                 description:
                     "Fill a string on the right side to a width of 15 with the character '─'",
                 example: "'nushell' | fill -a r -c '─' -w 15",
-                result: Some(Value::String {
-                    val: "────────nushell".into(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("────────nushell", Span::test_data())),
             },
             Example {
                 description: "Fill a string on both sides to a width of 15 with the character '─'",
                 example: "'nushell' | fill -a m -c '─' -w 15",
-                result: Some(Value::String {
-                    val: "────nushell────".into(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("────nushell────", Span::test_data())),
             },
             Example {
                 description:
                     "Fill a number on the left side to a width of 5 with the character '0'",
                 example: "1 | fill --alignment right --character '0' --width 5",
-                result: Some(Value::String {
-                    val: "00001".into(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("00001", Span::test_data())),
             },
             Example {
                 description: "Fill a number on both sides to a width of 5 with the character '0'",
                 example: "1.1 | fill --alignment center --character '0' --width 5",
-                result: Some(Value::String {
-                    val: "01.10".into(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("01.10", Span::test_data())),
             },
             Example {
                 description:
                     "Fill a filesize on the left side to a width of 5 with the character '0'",
                 example: "1kib | fill --alignment middle --character '0' --width 10",
-                result: Some(Value::String {
-                    val: "0001024000".into(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::string("0001024000", Span::test_data())),
             },
         ]
     }
@@ -198,14 +180,15 @@ fn action(input: &Value, args: &Arguments, span: Span) -> Value {
         Value::String { val, .. } => fill_string(val, args, span),
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => input.clone(),
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "int, filesize, float, string".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: span,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            span,
+        ),
     }
 }
 
@@ -213,18 +196,18 @@ fn fill_float(num: f64, args: &Arguments, span: Span) -> Value {
     let s = num.to_string();
     let out_str = pad(&s, args.width, &args.character, args.alignment, false);
 
-    Value::String { val: out_str, span }
+    Value::string(out_str, span)
 }
 fn fill_int(num: i64, args: &Arguments, span: Span) -> Value {
     let s = num.to_string();
     let out_str = pad(&s, args.width, &args.character, args.alignment, false);
 
-    Value::String { val: out_str, span }
+    Value::string(out_str, span)
 }
 fn fill_string(s: &str, args: &Arguments, span: Span) -> Value {
     let out_str = pad(s, args.width, &args.character, args.alignment, false);
 
-    Value::String { val: out_str, span }
+    Value::string(out_str, span)
 }
 
 fn pad(s: &str, width: usize, pad_char: &str, alignment: FillAlignment, truncate: bool) -> String {
