@@ -9,6 +9,7 @@ use nu_protocol::{
 
 pub struct Arguments {
     cell_paths: Option<Vec<CellPath>>,
+    compact: bool,
 }
 
 impl CmdArgument for Arguments {
@@ -39,6 +40,7 @@ impl Command for SubCommand {
                 (Type::Record(vec![]), Type::Record(vec![])),
             ])
             .allow_variants_without_examples(true) // TODO: supply exhaustive examples
+            .switch("compact", "output without padding zeros", Some('c'))
             .rest(
                 "rest",
                 SyntaxShape::CellPath,
@@ -70,29 +72,29 @@ impl Command for SubCommand {
             Example {
                 description: "convert string to a nushell binary primitive",
                 example: "'This is a string that is exactly 52 characters long.' | into binary",
-                result: Some(Value::Binary {
-                    val: "This is a string that is exactly 52 characters long."
+                result: Some(Value::binary(
+                    "This is a string that is exactly 52 characters long."
                         .to_string()
                         .as_bytes()
                         .to_vec(),
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a number to a nushell binary primitive",
                 example: "1 | into binary",
-                result: Some(Value::Binary {
-                    val: i64::from(1).to_le_bytes().to_vec(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(
+                    i64::from(1).to_ne_bytes().to_vec(),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a boolean to a nushell binary primitive",
                 example: "true | into binary",
-                result: Some(Value::Binary {
-                    val: i64::from(1).to_le_bytes().to_vec(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(
+                    i64::from(1).to_ne_bytes().to_vec(),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "convert a filesize to a nushell binary primitive",
@@ -105,12 +107,18 @@ impl Command for SubCommand {
                 result: None,
             },
             Example {
-                description: "convert a decimal to a nushell binary primitive",
+                description: "convert a float to a nushell binary primitive",
                 example: "1.234 | into binary",
-                result: Some(Value::Binary {
-                    val: 1.234f64.to_le_bytes().to_vec(),
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(
+                    1.234f64.to_ne_bytes().to_vec(),
+                    Span::test_data(),
+                )),
+            },
+            Example {
+                description:
+                    "convert an integer to a nushell binary primitive with compact enabled",
+                example: "10 | into binary --compact",
+                result: Some(Value::binary(vec![10], Span::test_data())),
             },
         ]
     }
@@ -127,93 +135,81 @@ fn into_binary(
     let cell_paths = (!cell_paths.is_empty()).then_some(cell_paths);
 
     match input {
-        PipelineData::ExternalStream { stdout: None, .. } => Ok(Value::Binary {
-            val: vec![],
-            span: head,
+        PipelineData::ExternalStream { stdout: None, .. } => {
+            Ok(Value::binary(vec![], head).into_pipeline_data())
         }
-        .into_pipeline_data()),
         PipelineData::ExternalStream {
             stdout: Some(stream),
             ..
         } => {
             // TODO: in the future, we may want this to stream out, converting each to bytes
             let output = stream.into_bytes()?;
-            Ok(Value::Binary {
-                val: output.item,
-                span: head,
-            }
-            .into_pipeline_data())
+            Ok(Value::binary(output.item, head).into_pipeline_data())
         }
         _ => {
-            let args = Arguments { cell_paths };
+            let args = Arguments {
+                cell_paths,
+                compact: call.has_flag("compact"),
+            };
             operate(action, args, input, call.head, engine_state.ctrlc.clone())
         }
     }
 }
 
-fn int_to_endian(n: i64) -> Vec<u8> {
-    if cfg!(target_endian = "little") {
-        n.to_le_bytes().to_vec()
-    } else {
-        n.to_be_bytes().to_vec()
-    }
-}
-
-fn float_to_endian(n: f64) -> Vec<u8> {
-    if cfg!(target_endian = "little") {
-        n.to_le_bytes().to_vec()
-    } else {
-        n.to_be_bytes().to_vec()
-    }
-}
-
 pub fn action(input: &Value, _args: &Arguments, span: Span) -> Value {
-    match input {
+    let value = match input {
         Value::Binary { .. } => input.clone(),
-        Value::Int { val, .. } => Value::Binary {
-            val: int_to_endian(*val),
-            span,
-        },
-        Value::Float { val, .. } => Value::Binary {
-            val: float_to_endian(*val),
-            span,
-        },
-        Value::Filesize { val, .. } => Value::Binary {
-            val: int_to_endian(*val),
-            span,
-        },
-        Value::String { val, .. } => Value::Binary {
-            val: val.as_bytes().to_vec(),
-            span,
-        },
-        Value::Bool { val, .. } => Value::Binary {
-            val: int_to_endian(i64::from(*val)),
-            span,
-        },
-        Value::Duration { val, .. } => Value::Binary {
-            val: int_to_endian(*val),
-            span,
-        },
-        Value::Date { val, .. } => Value::Binary {
-            val: val.format("%c").to_string().as_bytes().to_vec(),
-            span,
-        },
+        Value::Int { val, .. } => Value::binary(val.to_ne_bytes().to_vec(), span),
+        Value::Float { val, .. } => Value::binary(val.to_ne_bytes().to_vec(), span),
+        Value::Filesize { val, .. } => Value::binary(val.to_ne_bytes().to_vec(), span),
+        Value::String { val, .. } => Value::binary(val.as_bytes().to_vec(), span),
+        Value::Bool { val, .. } => Value::binary(i64::from(*val).to_ne_bytes().to_vec(), span),
+        Value::Duration { val, .. } => Value::binary(val.to_ne_bytes().to_vec(), span),
+        Value::Date { val, .. } => {
+            Value::binary(val.format("%c").to_string().as_bytes().to_vec(), span)
+        }
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => input.clone(),
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "integer, float, filesize, string, date, duration, binary or bool"
                     .into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: span,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            span,
+        ),
+    };
+
+    if _args.compact {
+        let val_span = value.span();
+        if let Value::Binary { val, .. } = value {
+            let val = if cfg!(target_endian = "little") {
+                match val.iter().rposition(|&x| x != 0) {
+                    Some(idx) => &val[..idx + 1],
+                    None => &val,
+                }
+            } else {
+                match val.iter().position(|&x| x != 0) {
+                    Some(idx) => &val[idx..],
+                    None => &val,
+                }
+            };
+
+            Value::binary(val.to_vec(), val_span)
+        } else {
+            value
+        }
+    } else {
+        value
     }
 }
 
 #[cfg(test)]
 mod test {
+    use rstest::rstest;
+
     use super::*;
 
     #[test]
@@ -222,4 +218,26 @@ mod test {
 
         test_examples(SubCommand {})
     }
+
+    #[rstest]
+    #[case(vec![10], vec![10], vec![10])]
+    #[case(vec![10, 0, 0], vec![10], vec![10, 0, 0])]
+    #[case(vec![0, 0, 10], vec![0, 0, 10], vec![10])]
+    #[case(vec![0, 10, 0, 0], vec![0, 10], vec![10, 0, 0])]
+    fn test_compact(#[case] input: Vec<u8>, #[case] little: Vec<u8>, #[case] big: Vec<u8>) {
+        let s = Value::test_binary(input);
+        let actual = action(
+            &s,
+            &Arguments {
+                cell_paths: None,
+                compact: true,
+            },
+            Span::test_data(),
+        );
+        if cfg!(target_endian = "little") {
+            assert_eq!(actual, Value::test_binary(little));
+        } else {
+            assert_eq!(actual, Value::test_binary(big));
+        }
+    }
 }
