@@ -154,10 +154,10 @@ impl Command for SubCommand {
 
     fn examples(&self) -> Vec<Example> {
         let example_result_1 = |nanos: i64| {
-            Some(Value::Date {
-                val: Utc.timestamp_nanos(nanos).into(),
-                span: Span::test_data(),
-            })
+            Some(Value::date(
+                Utc.timestamp_nanos(nanos).into(),
+                Span::test_data(),
+            ))
         };
         vec![
             Example {
@@ -195,35 +195,35 @@ impl Command for SubCommand {
             Example {
                 description: "Convert list of timestamps to datetimes",
                 example: r#"["2023-03-30 10:10:07 -05:00", "2023-05-05 13:43:49 -05:00", "2023-06-05 01:37:42 -05:00"] | into datetime"#,
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Date {
-                            val: DateTime::parse_from_str(
+                result: Some(Value::list(
+                    vec![
+                        Value::date(
+                            DateTime::parse_from_str(
                                 "2023-03-30 10:10:07 -05:00",
                                 "%Y-%m-%d %H:%M:%S %z",
                             )
                             .expect("date calculation should not fail in test"),
-                            span: Span::test_data(),
-                        },
-                        Value::Date {
-                            val: DateTime::parse_from_str(
+                            Span::test_data(),
+                        ),
+                        Value::date(
+                            DateTime::parse_from_str(
                                 "2023-05-05 13:43:49 -05:00",
                                 "%Y-%m-%d %H:%M:%S %z",
                             )
                             .expect("date calculation should not fail in test"),
-                            span: Span::test_data(),
-                        },
-                        Value::Date {
-                            val: DateTime::parse_from_str(
+                            Span::test_data(),
+                        ),
+                        Value::date(
+                            DateTime::parse_from_str(
                                 "2023-06-05 01:37:42 -05:00",
                                 "%Y-%m-%d %H:%M:%S %z",
                             )
                             .expect("date calculation should not fail in test"),
-                            span: Span::test_data(),
-                        },
+                            Span::test_data(),
+                        ),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -240,12 +240,7 @@ fn action(input: &Value, args: &Arguments, head: Span) -> Value {
     if matches!(input, Value::String { .. }) && dateformat.is_none() {
         if let Ok(input_val) = input.as_spanned_string() {
             match parse_date_from_string(&input_val.item, input_val.span) {
-                Ok(date) => {
-                    return Value::Date {
-                        val: date,
-                        span: input_val.span,
-                    }
-                }
+                Ok(date) => return Value::date(date, input_val.span),
                 Err(err) => err,
             };
         }
@@ -259,14 +254,15 @@ fn action(input: &Value, args: &Arguments, head: Span) -> Value {
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => return input.clone(),
         other => {
-            return Value::Error {
-                error: Box::new(ShellError::OnlySupportsThisInputType {
+            return Value::error(
+                ShellError::OnlySupportsThisInputType {
                     exp_input_type: "string and integer".into(),
                     wrong_type: other.get_type().to_string(),
                     dst_span: head,
-                    src_span: other.expect_span(),
-                }),
-            };
+                    src_span: other.span(),
+                },
+                head,
+            );
         }
     };
 
@@ -276,102 +272,87 @@ fn action(input: &Value, args: &Arguments, head: Span) -> Value {
                 // note all these `.timestamp_nanos()` could overflow if we didn't check range in `<date> | into int`.
 
                 // default to UTC
-                None => Value::Date {
-                    val: Utc.timestamp_nanos(ts).into(),
-                    span: head,
-                },
+                None => Value::date(Utc.timestamp_nanos(ts).into(), head),
                 Some(Spanned { item, span }) => match item {
                     Zone::Utc => {
                         let dt = Utc.timestamp_nanos(ts);
-                        Value::Date {
-                            val: dt.into(),
-                            span: *span,
-                        }
+                        Value::date(dt.into(), *span)
                     }
                     Zone::Local => {
                         let dt = Local.timestamp_nanos(ts);
-                        Value::Date {
-                            val: dt.into(),
-                            span: *span,
-                        }
+                        Value::date(dt.into(), *span)
                     }
                     Zone::East(i) => match FixedOffset::east_opt((*i as i32) * HOUR) {
                         Some(eastoffset) => {
                             let dt = eastoffset.timestamp_nanos(ts);
-                            Value::Date {
-                                val: dt,
-                                span: *span,
-                            }
+                            Value::date(dt, *span)
                         }
-                        None => Value::Error {
-                            error: Box::new(ShellError::DatetimeParseError(
-                                input.debug_value(),
-                                *span,
-                            )),
-                        },
+                        None => Value::error(
+                            ShellError::DatetimeParseError(input.debug_value(), *span),
+                            *span,
+                        ),
                     },
                     Zone::West(i) => match FixedOffset::west_opt((*i as i32) * HOUR) {
                         Some(westoffset) => {
                             let dt = westoffset.timestamp_nanos(ts);
-                            Value::Date {
-                                val: dt,
-                                span: *span,
-                            }
+                            Value::date(dt, *span)
                         }
-                        None => Value::Error {
-                            error: Box::new(ShellError::DatetimeParseError(
-                                input.debug_value(),
-                                *span,
-                            )),
-                        },
+                        None => Value::error(
+                            ShellError::DatetimeParseError(input.debug_value(), *span),
+                            *span,
+                        ),
                     },
-                    Zone::Error => Value::Error {
+                    Zone::Error => Value::error(
                         // This is an argument error, not an input error
-                        error: Box::new(ShellError::TypeMismatch {
+                        ShellError::TypeMismatch {
                             err_message: "Invalid timezone or offset".to_string(),
                             span: *span,
-                        }),
-                    },
+                        },
+                        *span,
+                    ),
                 },
             };
         };
     }
 
     // If input is not a timestamp, try parsing it as a string
+    let span = input.span();
     match input {
-        Value::String { val, span } => {
+        Value::String { val, .. } => {
             match dateformat {
                 Some(dt) => match DateTime::parse_from_str(val, &dt.0) {
-                    Ok(d) => Value::Date { val: d, span: head },
+                    Ok(d) => Value::date ( d, head ),
                     Err(reason) => {
-                        Value::Error {
-                            error: Box::new(ShellError::CantConvert { to_type: format!("could not parse as datetime using format '{}'", dt.0), from_type: reason.to_string(), span: head, help: Some("you can use `into datetime` without a format string to enable flexible parsing".to_string()) }),
-                        }
+                        Value::error (
+                            ShellError::CantConvert { to_type: format!("could not parse as datetime using format '{}'", dt.0), from_type: reason.to_string(), span: head, help: Some("you can use `into datetime` without a format string to enable flexible parsing".to_string()) },
+                            head,
+                        )
                     }
                 },
 
                 // Tries to automatically parse the date
                 // (i.e. without a format string)
                 // and assumes the system's local timezone if none is specified
-                None => match parse_date_from_string(val, *span) {
-                    Ok(date) => Value::Date {
-                        val: date,
-                        span: *span,
-                    },
+                None => match parse_date_from_string(val, span) {
+                    Ok(date) => Value::date (
+                        date,
+                        span,
+                    ),
                     Err(err) => err,
                 },
             }
         }
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => input.clone(),
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "string".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: head,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            head,
+        ),
     }
 }
 
@@ -398,11 +379,10 @@ mod tests {
             cell_paths: None,
         };
         let actual = action(&date_str, &args, Span::test_data());
-        let expected = Value::Date {
-            val: DateTime::parse_from_str("16.11.1984 8:00 am +0000", "%d.%m.%Y %H:%M %P %z")
-                .unwrap(),
-            span: Span::test_data(),
-        };
+        let expected = Value::date(
+            DateTime::parse_from_str("16.11.1984 8:00 am +0000", "%d.%m.%Y %H:%M %P %z").unwrap(),
+            Span::test_data(),
+        );
         assert_eq!(actual, expected)
     }
 
@@ -415,11 +395,10 @@ mod tests {
             cell_paths: None,
         };
         let actual = action(&date_str, &args, Span::test_data());
-        let expected = Value::Date {
-            val: DateTime::parse_from_str("2020-08-04T16:39:18+00:00", "%Y-%m-%dT%H:%M:%S%z")
-                .unwrap(),
-            span: Span::test_data(),
-        };
+        let expected = Value::date(
+            DateTime::parse_from_str("2020-08-04T16:39:18+00:00", "%Y-%m-%dT%H:%M:%S%z").unwrap(),
+            Span::test_data(),
+        );
         assert_eq!(actual, expected)
     }
 
@@ -436,11 +415,10 @@ mod tests {
             cell_paths: None,
         };
         let actual = action(&date_str, &args, Span::test_data());
-        let expected = Value::Date {
-            val: DateTime::parse_from_str("2021-02-27 21:55:40 +08:00", "%Y-%m-%d %H:%M:%S %z")
-                .unwrap(),
-            span: Span::test_data(),
-        };
+        let expected = Value::date(
+            DateTime::parse_from_str("2021-02-27 21:55:40 +08:00", "%Y-%m-%d %H:%M:%S %z").unwrap(),
+            Span::test_data(),
+        );
 
         assert_eq!(actual, expected)
     }
@@ -458,11 +436,10 @@ mod tests {
             cell_paths: None,
         };
         let actual = action(&date_int, &args, Span::test_data());
-        let expected = Value::Date {
-            val: DateTime::parse_from_str("2021-02-27 21:55:40 +08:00", "%Y-%m-%d %H:%M:%S %z")
-                .unwrap(),
-            span: Span::test_data(),
-        };
+        let expected = Value::date(
+            DateTime::parse_from_str("2021-02-27 21:55:40 +08:00", "%Y-%m-%d %H:%M:%S %z").unwrap(),
+            Span::test_data(),
+        );
 
         assert_eq!(actual, expected)
     }
@@ -480,10 +457,10 @@ mod tests {
             cell_paths: None,
         };
         let actual = action(&date_str, &args, Span::test_data());
-        let expected = Value::Date {
-            val: Local.timestamp_opt(1614434140, 0).unwrap().into(),
-            span: Span::test_data(),
-        };
+        let expected = Value::date(
+            Local.timestamp_opt(1614434140, 0).unwrap().into(),
+            Span::test_data(),
+        );
 
         assert_eq!(actual, expected)
     }
@@ -498,10 +475,10 @@ mod tests {
         };
         let actual = action(&date_str, &args, Span::test_data());
 
-        let expected = Value::Date {
-            val: Utc.timestamp_opt(1614434140, 0).unwrap().into(),
-            span: Span::test_data(),
-        };
+        let expected = Value::date(
+            Utc.timestamp_opt(1614434140, 0).unwrap().into(),
+            Span::test_data(),
+        );
 
         assert_eq!(actual, expected)
     }
