@@ -1,5 +1,4 @@
 use chrono::{FixedOffset, TimeZone};
-
 use nu_cmd_base::input_handler::{operate, CmdArgument};
 use nu_engine::CallExt;
 use nu_protocol::{
@@ -38,6 +37,7 @@ impl Command for SubCommand {
                 (Type::Date, Type::Int),
                 (Type::Duration, Type::Int),
                 (Type::Filesize, Type::Int),
+                (Type::Binary, Type::Int),
                 (Type::Table(vec![]), Type::Table(vec![])),
                 (Type::Record(vec![]), Type::Record(vec![])),
                 (
@@ -72,7 +72,12 @@ impl Command for SubCommand {
             ])
             .allow_variants_without_examples(true)
             .named("radix", SyntaxShape::Number, "radix of integer", Some('r'))
-            .switch("little-endian", "use little-endian byte decoding", None)
+            .named(
+                "endian",
+                SyntaxShape::String,
+                "byte encode endian, available options: native(default), little, big",
+                Some('e'),
+            )
             .rest(
                 "rest",
                 SyntaxShape::CellPath,
@@ -101,21 +106,50 @@ impl Command for SubCommand {
 
         let radix = call.get_flag::<Value>(engine_state, stack, "radix")?;
         let radix: u32 = match radix {
-            Some(Value::Int { val, span }) => {
-                if !(2..=36).contains(&val) {
-                    return Err(ShellError::TypeMismatch {
-                        err_message: "Radix must lie in the range [2, 36]".to_string(),
-                        span,
-                    });
+            Some(val) => {
+                let span = val.span();
+                match val {
+                    Value::Int { val, .. } => {
+                        if !(2..=36).contains(&val) {
+                            return Err(ShellError::TypeMismatch {
+                                err_message: "Radix must lie in the range [2, 36]".to_string(),
+                                span,
+                            });
+                        }
+                        val as u32
+                    }
+                    _ => 10,
                 }
-                val as u32
             }
-            Some(_) => 10,
             None => 10,
         };
+
+        let endian = call.get_flag::<Value>(engine_state, stack, "endian")?;
+        let little_endian = match endian {
+            Some(val) => {
+                let span = val.span();
+                match val {
+                    Value::String { val, .. } => match val.as_str() {
+                        "native" => cfg!(target_endian = "little"),
+                        "little" => true,
+                        "big" => false,
+                        _ => {
+                            return Err(ShellError::TypeMismatch {
+                                err_message: "Endian must be one of native, little, big"
+                                    .to_string(),
+                                span,
+                            })
+                        }
+                    },
+                    _ => false,
+                }
+            }
+            None => cfg!(target_endian = "little"),
+        };
+
         let args = Arguments {
             radix,
-            little_endian: call.has_flag("little-endian"),
+            little_endian,
             cell_paths,
         };
         operate(action, args, input, call.head, engine_state.ctrlc.clone())
@@ -134,7 +168,7 @@ impl Command for SubCommand {
                 result: Some(Value::test_int(2)),
             },
             Example {
-                description: "Convert decimal to integer",
+                description: "Convert float to integer",
                 example: "5.9 | into int",
                 result: Some(Value::test_int(5)),
             },
@@ -151,10 +185,10 @@ impl Command for SubCommand {
             Example {
                 description: "Convert bool to integer",
                 example: "[false, true] | into int",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(0), Value::test_int(1)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(0), Value::test_int(1)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Convert date to integer (Unix nanosecond timestamp)",
@@ -193,6 +227,7 @@ impl Command for SubCommand {
 fn action(input: &Value, args: &Arguments, span: Span) -> Value {
     let radix = args.radix;
     let little_endian = args.little_endian;
+    let val_span = input.span();
     match input {
         Value::Int { val: _, .. } => {
             if radix == 10 {
@@ -201,45 +236,35 @@ fn action(input: &Value, args: &Arguments, span: Span) -> Value {
                 convert_int(input, span, radix)
             }
         }
-        Value::Filesize { val, .. } => Value::Int { val: *val, span },
-        Value::Float { val, .. } => Value::Int {
-            val: {
+        Value::Filesize { val, .. } => Value::int(*val, span),
+        Value::Float { val, .. } => Value::int(
+            {
                 if radix == 10 {
                     *val as i64
                 } else {
-                    match convert_int(
-                        &Value::Int {
-                            val: *val as i64,
-                            span,
-                        },
-                        span,
-                        radix,
-                    )
-                    .as_i64()
-                    {
+                    match convert_int(&Value::int(*val as i64, span), span, radix).as_i64() {
                         Ok(v) => v,
                         _ => {
-                            return Value::Error {
-                                error: Box::new(ShellError::CantConvert {
+                            return Value::error(
+                                ShellError::CantConvert {
                                     to_type: "float".to_string(),
                                     from_type: "integer".to_string(),
                                     span,
                                     help: None,
-                                }),
-                            }
+                                },
+                                span,
+                            )
                         }
                     }
                 }
             },
             span,
-        },
+        ),
         Value::String { val, .. } => {
             if radix == 10 {
                 match int_from_string(val, span) {
-                    Ok(val) => Value::Int { val, span },
-                    Err(error) => Value::Error {
-                        error: Box::new(error),
-                    },
+                    Ok(val) => Value::int(val, span),
+                    Err(error) => Value::error(error, span),
                 }
             } else {
                 convert_int(input, span, radix)
@@ -247,15 +272,12 @@ fn action(input: &Value, args: &Arguments, span: Span) -> Value {
         }
         Value::Bool { val, .. } => {
             if *val {
-                Value::Int { val: 1, span }
+                Value::int(1, span)
             } else {
-                Value::Int { val: 0, span }
+                Value::int(0, span)
             }
         }
-        Value::Date {
-            val,
-            span: val_span,
-        } => {
+        Value::Date { val, .. } => {
             if val
                 < &FixedOffset::east_opt(0)
                     .expect("constant")
@@ -267,22 +289,20 @@ fn action(input: &Value, args: &Arguments, span: Span) -> Value {
                         .with_ymd_and_hms(2262, 4, 11, 23, 47, 16)
                         .unwrap()
             {
-                Value::Error {
-                    error: Box::new(ShellError::IncorrectValue {
+                Value::error (
+                    ShellError::IncorrectValue {
                         msg: "DateTime out of range for timestamp: 1677-09-21T00:12:43Z to 2262-04-11T23:47:16".to_string(),
-                        val_span: *val_span,
+                        val_span,
                         call_span: span,
-                    }),
-                }
-            } else {
-                Value::Int {
-                    val: val.timestamp_nanos(),
+                    },
                     span,
-                }
+                )
+            } else {
+                Value::int(val.timestamp_nanos_opt().unwrap_or_default(), span)
             }
         }
-        Value::Duration { val, .. } => Value::Int { val: *val, span },
-        Value::Binary { val, span } => {
+        Value::Duration { val, .. } => Value::int(*val, span),
+        Value::Binary { val, .. } => {
             use byteorder::{BigEndian, ByteOrder, LittleEndian};
 
             let mut val = val.to_vec();
@@ -293,27 +313,28 @@ fn action(input: &Value, args: &Arguments, span: Span) -> Value {
                 }
                 val.resize(8, 0);
 
-                Value::int(LittleEndian::read_i64(&val), *span)
+                Value::int(LittleEndian::read_i64(&val), val_span)
             } else {
                 while val.len() < 8 {
                     val.insert(0, 0);
                 }
                 val.resize(8, 0);
 
-                Value::int(BigEndian::read_i64(&val), *span)
+                Value::int(BigEndian::read_i64(&val), val_span)
             }
         }
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => input.clone(),
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "integer, float, filesize, date, string, binary, duration or bool"
                     .into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: span,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            span,
+        ),
     }
 }
 
@@ -329,21 +350,22 @@ fn convert_int(input: &Value, head: Span, radix: u32) -> Value {
             {
                 match int_from_string(val, head) {
                     Ok(x) => return Value::int(x, head),
-                    Err(e) => return Value::Error { error: Box::new(e) },
+                    Err(e) => return Value::error(e, head),
                 }
             } else if val.starts_with("00") {
                 // It's a padded string
                 match i64::from_str_radix(val, radix) {
                     Ok(n) => return Value::int(n, head),
                     Err(e) => {
-                        return Value::Error {
-                            error: Box::new(ShellError::CantConvert {
+                        return Value::error(
+                            ShellError::CantConvert {
                                 to_type: "string".to_string(),
                                 from_type: "int".to_string(),
                                 span: head,
                                 help: Some(e.to_string()),
-                            }),
-                        }
+                            },
+                            head,
+                        )
                     }
                 }
             }
@@ -352,26 +374,28 @@ fn convert_int(input: &Value, head: Span, radix: u32) -> Value {
         // Propagate errors by explicitly matching them before the final case.
         Value::Error { .. } => return input.clone(),
         other => {
-            return Value::Error {
-                error: Box::new(ShellError::OnlySupportsThisInputType {
+            return Value::error(
+                ShellError::OnlySupportsThisInputType {
                     exp_input_type: "string and integer".into(),
                     wrong_type: other.get_type().to_string(),
                     dst_span: head,
-                    src_span: other.expect_span(),
-                }),
-            };
+                    src_span: other.span(),
+                },
+                head,
+            );
         }
     };
     match i64::from_str_radix(i.trim(), radix) {
         Ok(n) => Value::int(n, head),
-        Err(_reason) => Value::Error {
-            error: Box::new(ShellError::CantConvert {
+        Err(_reason) => Value::error(
+            ShellError::CantConvert {
                 to_type: "string".to_string(),
                 from_type: "int".to_string(),
                 span: head,
                 help: None,
-            }),
-        },
+            },
+            head,
+        ),
     }
 }
 
@@ -559,7 +583,7 @@ mod test {
             },
             Span::test_data(),
         );
-        if let Value::Error { error } = actual {
+        if let Value::Error { error, .. } = actual {
             if let ShellError::IncorrectValue { msg: e, .. } = *error {
                 assert!(
                     e.contains(err_expected),
