@@ -5,6 +5,7 @@ mod datetime;
 mod decimal;
 mod duration;
 mod filesize;
+mod float;
 mod int;
 mod record;
 mod string;
@@ -16,6 +17,7 @@ pub use command::Into;
 pub use datetime::SubCommand as IntoDatetime;
 pub use decimal::SubCommand as IntoDecimal;
 pub use duration::SubCommand as IntoDuration;
+pub use float::SubCommand as IntoFloat;
 pub use int::SubCommand as IntoInt;
 pub use record::SubCommand as IntoRecord;
 pub use string::SubCommand as IntoString;
