@@ -3,10 +3,9 @@ use chrono::{DateTime, Datelike, FixedOffset, Local, Timelike};
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, PipelineData, ShellError::DatetimeParseError, ShellError::PipelineEmpty,
-    Signature, Span, Value,
+    record, Category, Example, PipelineData, Record, ShellError, ShellError::DatetimeParseError,
+    ShellError::PipelineEmpty, Signature, Span, Type, Value,
 };
-use nu_protocol::{ShellError, Type};
 
 #[derive(Clone)]
 pub struct SubCommand;
@@ -63,22 +62,16 @@ impl Command for SubCommand {
                 "timezone".into(),
             ];
             let vals = vec![
-                Value::Int { val: 2020, span },
-                Value::Int { val: 4, span },
-                Value::Int { val: 12, span },
-                Value::Int { val: 22, span },
-                Value::Int { val: 10, span },
-                Value::Int { val: 57, span },
-                Value::Int {
-                    val: 123_000_000,
-                    span,
-                },
-                Value::String {
-                    val: "+02:00".to_string(),
-                    span,
-                },
+                Value::int(2020, span),
+                Value::int(4, span),
+                Value::int(12, span),
+                Value::int(22, span),
+                Value::int(10, span),
+                Value::int(57, span),
+                Value::int(123_000_000, span),
+                Value::string("+02:00", span),
             ];
-            Some(Value::Record { cols, vals, span })
+            Some(Value::test_record(Record { cols, vals }))
         };
 
         let example_result_2 = || {
@@ -94,19 +87,16 @@ impl Command for SubCommand {
                 "timezone".into(),
             ];
             let vals = vec![
-                Value::Int { val: 2020, span },
-                Value::Int { val: 4, span },
-                Value::Int { val: 12, span },
-                Value::Int { val: 22, span },
-                Value::Int { val: 10, span },
-                Value::Int { val: 57, span },
-                Value::Int { val: 0, span },
-                Value::String {
-                    val: "+02:00".to_string(),
-                    span,
-                },
+                Value::int(2020, span),
+                Value::int(4, span),
+                Value::int(12, span),
+                Value::int(22, span),
+                Value::int(10, span),
+                Value::int(57, span),
+                Value::int(0, span),
+                Value::string("+02:00", span),
             ];
-            Some(Value::Record { cols, vals, span })
+            Some(Value::test_record(Record { cols, vals }))
         };
 
         vec![
@@ -134,57 +124,36 @@ impl Command for SubCommand {
     }
 }
 
-fn parse_date_into_table(date: Result<DateTime<FixedOffset>, Value>, head: Span) -> Value {
-    let cols = vec![
-        "year".into(),
-        "month".into(),
-        "day".into(),
-        "hour".into(),
-        "minute".into(),
-        "second".into(),
-        "nanosecond".into(),
-        "timezone".into(),
-    ];
-    match date {
-        Ok(x) => {
-            let vals = vec![
-                Value::int(x.year() as i64, head),
-                Value::int(x.month() as i64, head),
-                Value::int(x.day() as i64, head),
-                Value::int(x.hour() as i64, head),
-                Value::int(x.minute() as i64, head),
-                Value::int(x.second() as i64, head),
-                Value::int(x.nanosecond() as i64, head),
-                Value::string(x.offset().to_string(), head),
-            ];
-            Value::Record {
-                cols,
-                vals,
-                span: head,
-            }
-        }
-        Err(e) => e,
-    }
+fn parse_date_into_table(date: DateTime<FixedOffset>, head: Span) -> Value {
+    Value::record(
+        record! {
+            "year" => Value::int(date.year() as i64, head),
+            "month" => Value::int(date.month() as i64, head),
+            "day" => Value::int(date.day() as i64, head),
+            "hour" => Value::int(date.hour() as i64, head),
+            "minute" => Value::int(date.minute() as i64, head),
+            "second" => Value::int(date.second() as i64, head),
+            "nanosecond" => Value::int(date.nanosecond() as i64, head),
+            "timezone" => Value::string(date.offset().to_string(), head),
+        },
+        head,
+    )
 }
 
 fn helper(val: Value, head: Span) -> Value {
+    let span = val.span();
     match val {
-        Value::String {
-            val,
-            span: val_span,
-        } => {
-            let date = parse_date_from_string(&val, val_span);
-            parse_date_into_table(date, head)
-        }
-        Value::Nothing { span: _ } => {
+        Value::String { val, .. } => match parse_date_from_string(&val, span) {
+            Ok(date) => parse_date_into_table(date, head),
+            Err(e) => e,
+        },
+        Value::Nothing { .. } => {
             let now = Local::now();
             let n = now.with_timezone(now.offset());
-            parse_date_into_table(Ok(n), head)
+            parse_date_into_table(n, head)
         }
-        Value::Date { val, span: _ } => parse_date_into_table(Ok(val), head),
-        _ => Value::Error {
-            error: Box::new(DatetimeParseError(val.debug_value(), head)),
-        },
+        Value::Date { val, .. } => parse_date_into_table(val, head),
+        _ => Value::error(DatetimeParseError(val.debug_value(), head), head),
     }
 }
 
