@@ -2,8 +2,8 @@ use nu_engine::CallExt;
 use nu_protocol::ast::{Call, Expr, Expression};
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, DataSource, Example, IntoPipelineData, PipelineData, PipelineMetadata, ShellError,
-    Signature, Span, SyntaxShape, Type, Value,
+    record, Category, DataSource, Example, IntoPipelineData, PipelineData, PipelineMetadata,
+    Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -54,56 +54,51 @@ impl Command for Metadata {
                         } => {
                             let origin = stack.get_var_with_origin(*var_id, *span)?;
 
-                            Ok(build_metadata_record(&origin, &input.metadata(), head)
-                                .into_pipeline_data())
+                            Ok(
+                                build_metadata_record(&origin, input.metadata().as_deref(), head)
+                                    .into_pipeline_data(),
+                            )
                         }
                         _ => {
                             let val: Value = call.req(engine_state, stack, 0)?;
-                            Ok(build_metadata_record(&val, &input.metadata(), head)
-                                .into_pipeline_data())
+                            Ok(
+                                build_metadata_record(&val, input.metadata().as_deref(), head)
+                                    .into_pipeline_data(),
+                            )
                         }
                     }
                 } else {
                     let val: Value = call.req(engine_state, stack, 0)?;
-                    Ok(build_metadata_record(&val, &input.metadata(), head).into_pipeline_data())
+                    Ok(
+                        build_metadata_record(&val, input.metadata().as_deref(), head)
+                            .into_pipeline_data(),
+                    )
                 }
             }
             Some(_) => {
                 let val: Value = call.req(engine_state, stack, 0)?;
-                Ok(build_metadata_record(&val, &input.metadata(), head).into_pipeline_data())
+                Ok(
+                    build_metadata_record(&val, input.metadata().as_deref(), head)
+                        .into_pipeline_data(),
+                )
             }
             None => {
-                let mut cols = vec![];
-                let mut vals = vec![];
+                let mut record = Record::new();
                 if let Some(x) = input.metadata().as_deref() {
                     match x {
                         PipelineMetadata {
                             data_source: DataSource::Ls,
-                        } => {
-                            cols.push("source".into());
-                            vals.push(Value::string("ls", head))
-                        }
+                        } => record.push("source", Value::string("ls", head)),
                         PipelineMetadata {
                             data_source: DataSource::HtmlThemes,
-                        } => {
-                            cols.push("source".into());
-                            vals.push(Value::string("into html --list", head))
-                        }
+                        } => record.push("source", Value::string("into html --list", head)),
                         PipelineMetadata {
                             data_source: DataSource::Profiling(values),
-                        } => {
-                            cols.push("profiling".into());
-                            vals.push(Value::list(values.clone(), head))
-                        }
+                        } => record.push("profiling", Value::list(values.clone(), head)),
                     }
                 }
 
-                Ok(Value::Record {
-                    cols,
-                    vals,
-                    span: head,
-                }
-                .into_pipeline_data())
+                Ok(Value::record(record, head).into_pipeline_data())
             }
         }
     }
@@ -124,60 +119,36 @@ impl Command for Metadata {
     }
 }
 
-fn build_metadata_record(
-    arg: &Value,
-    metadata: &Option<Box<PipelineMetadata>>,
-    head: Span,
-) -> Value {
-    let mut cols = vec![];
-    let mut vals = vec![];
+fn build_metadata_record(arg: &Value, metadata: Option<&PipelineMetadata>, head: Span) -> Value {
+    let mut record = Record::new();
 
-    if let Ok(span) = arg.span() {
-        cols.push("span".into());
-        vals.push(Value::Record {
-            cols: vec!["start".into(), "end".into()],
-            vals: vec![
-                Value::Int {
-                    val: span.start as i64,
-                    span,
-                },
-                Value::Int {
-                    val: span.end as i64,
-                    span,
-                },
-            ],
-            span: head,
-        });
-    }
+    let span = arg.span();
+    record.push(
+        "span",
+        Value::record(
+            record! {
+                "start" => Value::int(span.start as i64,span),
+                "end" => Value::int(span.end as i64, span),
+            },
+            head,
+        ),
+    );
 
-    if let Some(x) = metadata.as_deref() {
+    if let Some(x) = metadata {
         match x {
             PipelineMetadata {
                 data_source: DataSource::Ls,
-            } => {
-                cols.push("source".into());
-                vals.push(Value::string("ls", head))
-            }
+            } => record.push("source", Value::string("ls", head)),
             PipelineMetadata {
                 data_source: DataSource::HtmlThemes,
-            } => {
-                cols.push("source".into());
-                vals.push(Value::string("into html --list", head))
-            }
+            } => record.push("source", Value::string("into html --list", head)),
             PipelineMetadata {
                 data_source: DataSource::Profiling(values),
-            } => {
-                cols.push("profiling".into());
-                vals.push(Value::list(values.clone(), head))
-            }
+            } => record.push("profiling", Value::list(values.clone(), head)),
         }
     }
 
-    Value::Record {
-        cols,
-        vals,
-        span: head,
-    }
+    Value::record(record, head)
 }
 
 #[cfg(test)]
