@@ -200,10 +200,11 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
         // FileSystem
         bind_command! {
             Cd,
-            Cp,
             Ls,
             Mkdir,
             Mv,
+            Cp,
+            UCp,
             Open,
             Start,
             Rm,
@@ -287,6 +288,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             IntoDatetime,
             IntoDecimal,
             IntoDuration,
+            IntoFloat,
             IntoFilesize,
             IntoInt,
             IntoRecord,
@@ -366,6 +368,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             RandomChars,
             RandomDecimal,
             RandomDice,
+            RandomFloat,
             RandomInteger,
             RandomUuid,
         };
