@@ -200,9 +200,7 @@ impl Command for Mv {
                     update_mode,
                 );
                 if let Err(error) = result {
-                    Some(Value::Error {
-                        error: Box::new(error),
-                    })
+                    Some(Value::error(error, spanned_source.span))
                 } else if verbose {
                     let val = match result {
                         Ok(true) => format!(
@@ -216,7 +214,7 @@ impl Command for Mv {
                             destination.to_string_lossy()
                         ),
                     };
-                    Some(Value::String { val, span })
+                    Some(Value::string(val, span))
                 } else {
                     None
                 }
