@@ -44,58 +44,55 @@ impl Command for DropNth {
             Example {
                 example: "[sam,sarah,2,3,4,5] | drop nth 0 1 2",
                 description: "Drop the first, second, and third row",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(3), Value::test_int(4), Value::test_int(5)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(3), Value::test_int(4), Value::test_int(5)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 example: "[0,1,2,3,4,5] | drop nth 0 1 2",
                 description: "Drop the first, second, and third row",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(3), Value::test_int(4), Value::test_int(5)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(3), Value::test_int(4), Value::test_int(5)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 example: "[0,1,2,3,4,5] | drop nth 0 2 4",
                 description: "Drop rows 0 2 4",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(1), Value::test_int(3), Value::test_int(5)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(1), Value::test_int(3), Value::test_int(5)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 example: "[0,1,2,3,4,5] | drop nth 2 0 4",
                 description: "Drop rows 2 0 4",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(1), Value::test_int(3), Value::test_int(5)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(1), Value::test_int(3), Value::test_int(5)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Drop range rows from second to fourth",
                 example: "[first second third fourth fifth] | drop nth (1..3)",
-                result: Some(Value::List {
-                    vals: vec![Value::test_string("first"), Value::test_string("fifth")],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_string("first"), Value::test_string("fifth")],
+                    Span::test_data(),
+                )),
             },
             Example {
                 example: "[0,1,2,3,4,5] | drop nth 1..",
                 description: "Drop all rows except first row",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(0)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(vec![Value::test_int(0)], Span::test_data())),
             },
             Example {
                 example: "[0,1,2,3,4,5] | drop nth 3..",
                 description: "Drop rows 3,4,5",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(0), Value::test_int(1), Value::test_int(2)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(0), Value::test_int(1), Value::test_int(2)],
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -145,7 +142,7 @@ impl Command for DropNth {
                 let mut to = to as usize;
                 let from = from as usize;
 
-                if let PipelineData::Value(Value::List { ref vals, span: _ }, _) = input {
+                if let PipelineData::Value(Value::List { ref vals, .. }, _) = input {
                     let max = from + vals.len() - 1;
                     if to > max {
                         to = max;
@@ -196,7 +193,7 @@ fn extract_int_or_range(
         .or(range_opt)
         .ok_or_else(|| ShellError::TypeMismatch {
             err_message: "int or range".into(),
-            span: value.span().unwrap_or_else(|_| Span::new(0, 0)),
+            span: value.span(),
         })
 }
 
