@@ -1,8 +1,8 @@
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoInterruptiblePipelineData, PipelineData, ShellError, Signature, Span,
-    Type, Value,
+    record, Category, Example, IntoInterruptiblePipelineData, PipelineData, Record, ShellError,
+    Signature, Span, Type, Value,
 };
 
 #[derive(Clone)]
@@ -31,26 +31,23 @@ impl Command for Enumerate {
         vec![Example {
             description: "Add an index to each element of a list",
             example: r#"[a, b, c] | enumerate "#,
-            result: Some(Value::List {
-                vals: vec![
-                    Value::Record {
+            result: Some(Value::list(
+                vec![
+                    Value::test_record(Record {
                         cols: vec!["index".into(), "item".into()],
                         vals: vec![Value::test_int(0), Value::test_string("a")],
-                        span: Span::test_data(),
-                    },
-                    Value::Record {
+                    }),
+                    Value::test_record(Record {
                         cols: vec!["index".into(), "item".into()],
                         vals: vec![Value::test_int(1), Value::test_string("b")],
-                        span: Span::test_data(),
-                    },
-                    Value::Record {
+                    }),
+                    Value::test_record(Record {
                         cols: vec!["index".into(), "item".into()],
                         vals: vec![Value::test_int(2), Value::test_string("c")],
-                        span: Span::test_data(),
-                    },
+                    }),
                 ],
-                span: Span::test_data(),
-            }),
+                Span::test_data(),
+            )),
         }]
     }
 
@@ -68,16 +65,14 @@ impl Command for Enumerate {
         Ok(input
             .into_iter()
             .enumerate()
-            .map(move |(idx, x)| Value::Record {
-                cols: vec!["index".into(), "item".into()],
-                vals: vec![
-                    Value::Int {
-                        val: idx as i64,
-                        span,
+            .map(move |(idx, x)| {
+                Value::record(
+                    record! {
+                        "index" => Value::int(idx as i64, span),
+                        "item" => x,
                     },
-                    x,
-                ],
-                span,
+                    span,
+                )
             })
             .into_pipeline_data_with_metadata(metadata, ctrlc))
     }
