@@ -1,8 +1,8 @@
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Config, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span, Type,
-    Value,
+    Category, Config, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span,
+    Type, Value,
 };
 
 #[derive(Clone)]
@@ -36,45 +36,42 @@ impl Command for Headers {
             Example {
                 description: "Sets the column names for a table created by `split column`",
                 example: r#""a b c|1 2 3" | split row "|" | split column " " | headers"#,
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list(
+                    vec![Value::test_record(Record {
                         cols: columns.clone(),
                         vals: vec![
                             Value::test_string("1"),
                             Value::test_string("2"),
                             Value::test_string("3"),
                         ],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Columns which don't have data in their first row are removed",
                 example: r#""a b c|1 2 3|1 2 3 4" | split row "|" | split column " " | headers"#,
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::Record {
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: columns.clone(),
                             vals: vec![
                                 Value::test_string("1"),
                                 Value::test_string("2"),
                                 Value::test_string("3"),
                             ],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: columns,
                             vals: vec![
                                 Value::test_string("1"),
                                 Value::test_string("2"),
                                 Value::test_string("3"),
                             ],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -101,33 +98,31 @@ fn replace_headers(
     old_headers: &[String],
     new_headers: &[String],
 ) -> Result<Value, ShellError> {
+    let span = value.span();
     match value {
-        Value::Record { cols, vals, span } => {
-            let (cols, vals) = cols
-                .into_iter()
-                .zip(vals)
+        Value::Record { val, .. } => Ok(Value::record(
+            val.into_iter()
                 .filter_map(|(col, val)| {
                     old_headers
                         .iter()
                         .position(|c| c == &col)
                         .map(|i| (new_headers[i].clone(), val))
                 })
-                .unzip();
-
-            Ok(Value::Record { cols, vals, span })
-        }
-        Value::List { vals, span } => {
+                .collect(),
+            span,
+        )),
+        Value::List { vals, .. } => {
             let vals = vals
                 .into_iter()
                 .skip(1)
                 .map(|value| replace_headers(value, old_headers, new_headers))
                 .collect::<Result<Vec<Value>, ShellError>>()?;
 
-            Ok(Value::List { vals, span })
+            Ok(Value::list(vals, span))
         }
         _ => Err(ShellError::TypeMismatch {
             err_message: "record".to_string(),
-            span: value.span()?,
+            span: value.span(),
         }),
     }
 }
@@ -135,11 +130,11 @@ fn replace_headers(
 fn is_valid_header(value: &Value) -> bool {
     matches!(
         value,
-        Value::Nothing { span: _ }
-            | Value::String { val: _, span: _ }
-            | Value::Bool { val: _, span: _ }
-            | Value::Float { val: _, span: _ }
-            | Value::Int { val: _, span: _ }
+        Value::Nothing { .. }
+            | Value::String { val: _, .. }
+            | Value::Bool { val: _, .. }
+            | Value::Float { val: _, .. }
+            | Value::Int { val: _, .. }
     )
 }
 
@@ -147,20 +142,22 @@ fn extract_headers(
     value: &Value,
     config: &Config,
 ) -> Result<(Vec<String>, Vec<String>), ShellError> {
+    let span = value.span();
     match value {
-        Value::Record { cols, vals, .. } => {
-            for v in vals {
+        Value::Record { val: record, .. } => {
+            for v in &record.vals {
                 if !is_valid_header(v) {
                     return Err(ShellError::TypeMismatch {
                         err_message: "needs compatible type: Null, String, Bool, Float, Int"
                             .to_string(),
-                        span: v.span()?,
+                        span: v.span(),
                     });
                 }
             }
 
-            let old_headers = cols.to_vec();
-            let new_headers = vals
+            let old_headers = record.cols.clone();
+            let new_headers = record
+                .vals
                 .iter()
                 .enumerate()
                 .map(|(idx, value)| {
@@ -175,7 +172,7 @@ fn extract_headers(
 
             Ok((old_headers, new_headers))
         }
-        Value::List { vals, span } => vals
+        Value::List { vals, .. } => vals
             .iter()
             .map(|value| extract_headers(value, config))
             .next()
@@ -183,14 +180,14 @@ fn extract_headers(
                 ShellError::GenericError(
                     "Found empty list".to_string(),
                     "unable to extract headers".to_string(),
-                    Some(*span),
+                    Some(span),
                     None,
                     Vec::new(),
                 )
             })?,
         _ => Err(ShellError::TypeMismatch {
             err_message: "record".to_string(),
-            span: value.span()?,
+            span: value.span(),
         }),
     }
 }
