@@ -3,7 +3,8 @@ use nu_engine::{eval_block_with_early_return, CallExt};
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Closure, Command, EngineState, Stack};
 use nu_protocol::{
-    Example, IntoPipelineData, PipelineData, ShellError, Signature, SyntaxShape, Type, Value,
+    Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, SyntaxShape, Type,
+    Value,
 };
 
 #[derive(Clone)]
@@ -37,6 +38,7 @@ impl Command for Reduce {
                 "reducing function",
             )
             .allow_variants_without_examples(true)
+            .category(Category::Filters)
     }
 
     fn usage(&self) -> &str {
