@@ -2,8 +2,8 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoInterruptiblePipelineData, PipelineData, ShellError, Signature, Span,
-    SyntaxShape, Type, Value,
+    Category, Example, IntoInterruptiblePipelineData, PipelineData, Record, ShellError, Signature,
+    Span, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -54,33 +54,33 @@ impl Command for Take {
         let metadata = input.metadata();
 
         match input {
-            PipelineData::Value(val, _) => match val {
-                Value::List { vals, .. } => Ok(vals
-                    .into_iter()
-                    .take(rows_desired)
-                    .into_pipeline_data(ctrlc)
-                    .set_metadata(metadata)),
-                Value::Binary { val, span } => {
-                    let slice: Vec<u8> = val.into_iter().take(rows_desired).collect();
-                    Ok(PipelineData::Value(
-                        Value::Binary { val: slice, span },
-                        metadata,
-                    ))
+            PipelineData::Value(val, _) => {
+                let span = val.span();
+                match val {
+                    Value::List { vals, .. } => Ok(vals
+                        .into_iter()
+                        .take(rows_desired)
+                        .into_pipeline_data(ctrlc)
+                        .set_metadata(metadata)),
+                    Value::Binary { val, .. } => {
+                        let slice: Vec<u8> = val.into_iter().take(rows_desired).collect();
+                        Ok(PipelineData::Value(Value::binary(slice, span), metadata))
+                    }
+                    Value::Range { val, .. } => Ok(val
+                        .into_range_iter(ctrlc.clone())?
+                        .take(rows_desired)
+                        .into_pipeline_data(ctrlc)
+                        .set_metadata(metadata)),
+                    // Propagate errors by explicitly matching them before the final case.
+                    Value::Error { error, .. } => Err(*error),
+                    other => Err(ShellError::OnlySupportsThisInputType {
+                        exp_input_type: "list, binary or range".into(),
+                        wrong_type: other.get_type().to_string(),
+                        dst_span: call.head,
+                        src_span: other.span(),
+                    }),
                 }
-                Value::Range { val, .. } => Ok(val
-                    .into_range_iter(ctrlc.clone())?
-                    .take(rows_desired)
-                    .into_pipeline_data(ctrlc)
-                    .set_metadata(metadata)),
-                // Propagate errors by explicitly matching them before the final case.
-                Value::Error { error } => Err(*error),
-                other => Err(ShellError::OnlySupportsThisInputType {
-                    exp_input_type: "list, binary or range".into(),
-                    wrong_type: other.get_type().to_string(),
-                    dst_span: call.head,
-                    src_span: other.expect_span(),
-                }),
-            },
+            }
             PipelineData::ListStream(ls, metadata) => Ok(ls
                 .take(rows_desired)
                 .into_pipeline_data(ctrlc)
@@ -107,45 +107,45 @@ impl Command for Take {
             Example {
                 description: "Return the first item of a list/table",
                 example: "[1 2 3] | take 1",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(1)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(vec![Value::test_int(1)], Span::test_data())),
             },
             Example {
                 description: "Return the first 2 items of a list/table",
                 example: "[1 2 3] | take 2",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(1), Value::test_int(2)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(1), Value::test_int(2)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Return the first two rows of a table",
                 example: "[[editions]; [2015] [2018] [2021]] | take 2",
-                result: Some(Value::List {
-                    vals: vec![
-                        Value::test_record(vec!["editions"], vec![Value::test_int(2015)]),
-                        Value::test_record(vec!["editions"], vec![Value::test_int(2018)]),
+                result: Some(Value::list(
+                    vec![
+                        Value::test_record(Record {
+                            cols: vec!["editions".to_string()],
+                            vals: vec![Value::test_int(2015)],
+                        }),
+                        Value::test_record(Record {
+                            cols: vec!["editions".to_string()],
+                            vals: vec![Value::test_int(2018)],
+                        }),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Return the first 2 bytes of a binary value",
                 example: "0x[01 23 45] | take 2",
-                result: Some(Value::Binary {
-                    val: vec![0x01, 0x23],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::binary(vec![0x01, 0x23], Span::test_data())),
             },
             Example {
                 description: "Return the first 3 elements of a range",
                 example: "1..10 | take 3",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(1), Value::test_int(2), Value::test_int(3)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(1), Value::test_int(2), Value::test_int(3)],
+                    Span::test_data(),
+                )),
             },
         ]
     }
