@@ -7,9 +7,10 @@ use nu_protocol::{
 
 pub fn chain_error_with_input(
     error_source: ShellError,
-    input_span: Result<Span, ShellError>,
+    input_is_error: bool,
+    span: Span,
 ) -> ShellError {
-    if let Ok(span) = input_span {
+    if !input_is_error {
         return ShellError::EvalBlockWithInput(span, vec![error_source]);
     }
     error_source
@@ -61,19 +62,11 @@ pub fn boolean_fold(
             }
             Ok(pipeline_data) => {
                 if pipeline_data.into_value(span).is_true() == accumulator {
-                    return Ok(Value::Bool {
-                        val: accumulator,
-                        span,
-                    }
-                    .into_pipeline_data());
+                    return Ok(Value::bool(accumulator, span).into_pipeline_data());
                 }
             }
         }
     }
 
-    Ok(Value::Bool {
-        val: !accumulator,
-        span,
-    }
-    .into_pipeline_data())
+    Ok(Value::bool(!accumulator, span).into_pipeline_data())
 }
