@@ -1,8 +1,8 @@
 use nu_protocol::ast::{Call, Expr, Expression, PipelineElement};
 use nu_protocol::engine::{Command, EngineState, Stack, StateWorkingSet};
 use nu_protocol::{
-    Category, Example, IntoPipelineData, PipelineData, Range, ShellError, Signature, Span, Type,
-    Unit, Value,
+    Category, Example, IntoPipelineData, PipelineData, Range, Record, ShellError, Signature, Span,
+    Type, Unit, Value,
 };
 #[derive(Clone)]
 pub struct FromNuon;
@@ -27,26 +27,24 @@ impl Command for FromNuon {
             Example {
                 example: "'{ a:1 }' | from nuon",
                 description: "Converts nuon formatted string to table",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["a".to_string()],
                     vals: vec![Value::test_int(1)],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             Example {
                 example: "'{ a:1, b: [1, 2] }' | from nuon",
                 description: "Converts nuon formatted string to table",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["a".to_string(), "b".to_string()],
                     vals: vec![
                         Value::test_int(1),
-                        Value::List {
-                            vals: vec![Value::test_int(1), Value::test_int(2)],
-                            span: Span::test_data(),
-                        },
+                        Value::list(
+                            vec![Value::test_int(1), Value::test_int(2)],
+                            Span::test_data(),
+                        ),
                     ],
-                    span: Span::test_data(),
-                }),
+                })),
             },
         ]
     }
@@ -208,8 +206,8 @@ fn convert_to_value(
             "closures not supported in nuon".into(),
             expr.span,
         )),
-        Expr::Binary(val) => Ok(Value::Binary { val, span }),
-        Expr::Bool(val) => Ok(Value::Bool { val, span }),
+        Expr::Binary(val) => Ok(Value::binary(val, span)),
+        Expr::Bool(val) => Ok(Value::bool(val, span)),
         Expr::Call(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
             "Error when loading".into(),
@@ -222,16 +220,16 @@ fn convert_to_value(
             "subexpressions and cellpaths not supported in nuon".into(),
             expr.span,
         )),
-        Expr::DateTime(dt) => Ok(Value::Date { val: dt, span }),
+        Expr::DateTime(dt) => Ok(Value::date(dt, span)),
         Expr::ExternalCall(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
             "Error when loading".into(),
             "calls not supported in nuon".into(),
             expr.span,
         )),
-        Expr::Filepath(val) => Ok(Value::String { val, span }),
-        Expr::Directory(val) => Ok(Value::String { val, span }),
-        Expr::Float(val) => Ok(Value::Float { val, span }),
+        Expr::Filepath(val) => Ok(Value::string(val, span)),
+        Expr::Directory(val) => Ok(Value::string(val, span)),
+        Expr::Float(val) => Ok(Value::float(val, span)),
         Expr::FullCellPath(full_cell_path) => {
             if !full_cell_path.tail.is_empty() {
                 Err(ShellError::OutsideSpannedLabeledError(
@@ -257,7 +255,7 @@ fn convert_to_value(
             "extra tokens in input file".into(),
             expr.span,
         )),
-        Expr::GlobPattern(val) => Ok(Value::String { val, span }),
+        Expr::GlobPattern(val) => Ok(Value::string(val, span)),
         Expr::ImportPattern(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
             "Error when loading".into(),
@@ -270,7 +268,7 @@ fn convert_to_value(
             "overlays not supported in nuon".into(),
             expr.span,
         )),
-        Expr::Int(val) => Ok(Value::Int { val, span }),
+        Expr::Int(val) => Ok(Value::int(val, span)),
         Expr::Keyword(kw, ..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
             "Error when loading".into(),
@@ -283,7 +281,7 @@ fn convert_to_value(
                 output.push(convert_to_value(val, span, original_text)?);
             }
 
-            Ok(Value::List { vals: output, span })
+            Ok(Value::list(output, span))
         }
         Expr::MatchBlock(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
@@ -291,7 +289,7 @@ fn convert_to_value(
             "match blocks not supported in nuon".into(),
             expr.span,
         )),
-        Expr::Nothing => Ok(Value::Nothing { span }),
+        Expr::Nothing => Ok(Value::nothing(span)),
         Expr::Operator(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
             "Error when loading".into(),
@@ -302,29 +300,28 @@ fn convert_to_value(
             let from = if let Some(f) = from {
                 convert_to_value(*f, span, original_text)?
             } else {
-                Value::Nothing { span: expr.span }
+                Value::nothing(expr.span)
             };
 
             let next = if let Some(s) = next {
                 convert_to_value(*s, span, original_text)?
             } else {
-                Value::Nothing { span: expr.span }
+                Value::nothing(expr.span)
             };
 
             let to = if let Some(t) = to {
                 convert_to_value(*t, span, original_text)?
             } else {
-                Value::Nothing { span: expr.span }
+                Value::nothing(expr.span)
             };
 
-            Ok(Value::Range {
-                val: Box::new(Range::new(expr.span, from, next, to, &operator)?),
-                span: expr.span,
-            })
+            Ok(Value::range(
+                Range::new(expr.span, from, next, to, &operator)?,
+                expr.span,
+            ))
         }
         Expr::Record(key_vals) => {
-            let mut cols = vec![];
-            let mut vals = vec![];
+            let mut record = Record::new();
 
             for (key, val) in key_vals {
                 let key_str = match key.expr {
@@ -341,11 +338,10 @@ fn convert_to_value(
 
                 let value = convert_to_value(val, span, original_text)?;
 
-                cols.push(key_str);
-                vals.push(value);
+                record.push(key_str, value);
             }
 
-            Ok(Value::Record { cols, vals, span })
+            Ok(Value::record(record, span))
         }
         Expr::RowCondition(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
@@ -359,7 +355,7 @@ fn convert_to_value(
             "signatures not supported in nuon".into(),
             expr.span,
         )),
-        Expr::String(s) => Ok(Value::String { val: s, span }),
+        Expr::String(s) => Ok(Value::string(s, span)),
         Expr::StringInterpolation(..) => Err(ShellError::OutsideSpannedLabeledError(
             original_text.to_string(),
             "Error when loading".into(),
@@ -409,14 +405,16 @@ fn convert_to_value(
                     ));
                 }
 
-                output.push(Value::Record {
-                    cols: cols.clone(),
-                    vals,
+                output.push(Value::record(
+                    Record {
+                        cols: cols.clone(),
+                        vals,
+                    },
                     span,
-                });
+                ));
             }
 
-            Ok(Value::List { vals: output, span })
+            Ok(Value::list(output, span))
         }
         Expr::ValueWithUnit(val, unit) => {
             let size = match val.expr {
@@ -432,80 +430,41 @@ fn convert_to_value(
             };
 
             match unit.item {
-                Unit::Byte => Ok(Value::Filesize { val: size, span }),
-                Unit::Kilobyte => Ok(Value::Filesize {
-                    val: size * 1000,
+                Unit::Byte => Ok(Value::filesize(size, span)),
+                Unit::Kilobyte => Ok(Value::filesize(size * 1000, span)),
+                Unit::Megabyte => Ok(Value::filesize(size * 1000 * 1000, span)),
+                Unit::Gigabyte => Ok(Value::filesize(size * 1000 * 1000 * 1000, span)),
+                Unit::Terabyte => Ok(Value::filesize(size * 1000 * 1000 * 1000 * 1000, span)),
+                Unit::Petabyte => Ok(Value::filesize(
+                    size * 1000 * 1000 * 1000 * 1000 * 1000,
                     span,
-                }),
-                Unit::Megabyte => Ok(Value::Filesize {
-                    val: size * 1000 * 1000,
+                )),
+                Unit::Exabyte => Ok(Value::filesize(
+                    size * 1000 * 1000 * 1000 * 1000 * 1000 * 1000,
                     span,
-                }),
-                Unit::Gigabyte => Ok(Value::Filesize {
-                    val: size * 1000 * 1000 * 1000,
-                    span,
-                }),
-                Unit::Terabyte => Ok(Value::Filesize {
-                    val: size * 1000 * 1000 * 1000 * 1000,
-                    span,
-                }),
-                Unit::Petabyte => Ok(Value::Filesize {
-                    val: size * 1000 * 1000 * 1000 * 1000 * 1000,
-                    span,
-                }),
-                Unit::Exabyte => Ok(Value::Filesize {
-                    val: size * 1000 * 1000 * 1000 * 1000 * 1000 * 1000,
-                    span,
-                }),
+                )),
 
-                Unit::Kibibyte => Ok(Value::Filesize {
-                    val: size * 1024,
+                Unit::Kibibyte => Ok(Value::filesize(size * 1024, span)),
+                Unit::Mebibyte => Ok(Value::filesize(size * 1024 * 1024, span)),
+                Unit::Gibibyte => Ok(Value::filesize(size * 1024 * 1024 * 1024, span)),
+                Unit::Tebibyte => Ok(Value::filesize(size * 1024 * 1024 * 1024 * 1024, span)),
+                Unit::Pebibyte => Ok(Value::filesize(
+                    size * 1024 * 1024 * 1024 * 1024 * 1024,
                     span,
-                }),
-                Unit::Mebibyte => Ok(Value::Filesize {
-                    val: size * 1024 * 1024,
+                )),
+                Unit::Exbibyte => Ok(Value::filesize(
+                    size * 1024 * 1024 * 1024 * 1024 * 1024 * 1024,
                     span,
-                }),
-                Unit::Gibibyte => Ok(Value::Filesize {
-                    val: size * 1024 * 1024 * 1024,
-                    span,
-                }),
-                Unit::Tebibyte => Ok(Value::Filesize {
-                    val: size * 1024 * 1024 * 1024 * 1024,
-                    span,
-                }),
-                Unit::Pebibyte => Ok(Value::Filesize {
-                    val: size * 1024 * 1024 * 1024 * 1024 * 1024,
-                    span,
-                }),
-                Unit::Exbibyte => Ok(Value::Filesize {
-                    val: size * 1024 * 1024 * 1024 * 1024 * 1024 * 1024,
-                    span,
-                }),
+                )),
 
-                Unit::Nanosecond => Ok(Value::Duration { val: size, span }),
-                Unit::Microsecond => Ok(Value::Duration {
-                    val: size * 1000,
-                    span,
-                }),
-                Unit::Millisecond => Ok(Value::Duration {
-                    val: size * 1000 * 1000,
-                    span,
-                }),
-                Unit::Second => Ok(Value::Duration {
-                    val: size * 1000 * 1000 * 1000,
-                    span,
-                }),
-                Unit::Minute => Ok(Value::Duration {
-                    val: size * 1000 * 1000 * 1000 * 60,
-                    span,
-                }),
-                Unit::Hour => Ok(Value::Duration {
-                    val: size * 1000 * 1000 * 1000 * 60 * 60,
-                    span,
-                }),
+                Unit::Nanosecond => Ok(Value::duration(size, span)),
+                Unit::Microsecond => Ok(Value::duration(size * 1000, span)),
+                Unit::Millisecond => Ok(Value::duration(size * 1000 * 1000, span)),
+                Unit::Second => Ok(Value::duration(size * 1000 * 1000 * 1000, span)),
+                Unit::Minute => Ok(Value::duration(size * 1000 * 1000 * 1000 * 60, span)),
+                Unit::Hour => Ok(Value::duration(size * 1000 * 1000 * 1000 * 60 * 60, span)),
                 Unit::Day => match size.checked_mul(1000 * 1000 * 1000 * 60 * 60 * 24) {
-                    Some(val) => Ok(Value::Duration { val, span }),
+                    Some(val) => Ok(Value::duration(val, span)),
                     None => Err(ShellError::OutsideSpannedLabeledError(
                         original_text.to_string(),
                         "day duration too large".into(),
@@ -515,7 +474,7 @@ fn convert_to_value(
                 },
 
                 Unit::Week => match size.checked_mul(1000 * 1000 * 1000 * 60 * 60 * 24 * 7) {
-                    Some(val) => Ok(Value::Duration { val, span }),
+                    Some(val) => Ok(Value::duration(val, span)),
                     None => Err(ShellError::OutsideSpannedLabeledError(
                         original_text.to_string(),
                         "week duration too large".into(),
