@@ -3,8 +3,8 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span, Spanned,
-    SyntaxShape, Type, Value,
+    Category, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span,
+    Spanned, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -44,13 +44,32 @@ impl Command for FromSsv {
             example: r#"'FOO   BAR
 1   2' | from ssv"#,
             description: "Converts ssv formatted string to table",
-            result: Some(Value::List { vals: vec![Value::Record { cols: vec!["FOO".to_string(), "BAR".to_string()], vals: vec![Value::test_string("1"), Value::test_string("2")], span: Span::test_data() }], span: Span::test_data() }),
+            result: Some(Value::list(
+                vec![Value::test_record(Record {
+                    cols: vec!["FOO".to_string(), "BAR".to_string()],
+                    vals: vec![Value::test_string("1"), Value::test_string("2")],
+                })],
+                Span::test_data(),
+            )),
         }, Example {
             example: r#"'FOO   BAR
 1   2' | from ssv -n"#,
             description: "Converts ssv formatted string to table but not treating the first row as column names",
             result: Some(
-                Value::List { vals: vec![Value::Record { cols: vec!["column1".to_string(), "column2".to_string()], vals: vec![Value::test_string("FOO"), Value::test_string("BAR")], span: Span::test_data() }, Value::Record { cols: vec!["column1".to_string(), "column2".to_string()], vals: vec![Value::test_string("1"), Value::test_string("2")], span: Span::test_data() }], span: Span::test_data() }),
+                Value::list(
+                    vec![
+                        Value::test_record(Record {
+                            cols: vec!["column1".to_string(), "column2".to_string()],
+                            vals: vec![Value::test_string("FOO"), Value::test_string("BAR")],
+                        }),
+                        Value::test_record(Record {
+                            cols: vec!["column1".to_string(), "column2".to_string()],
+                            vals: vec![Value::test_string("1"), Value::test_string("2")],
+                        }),
+                    ],
+                    Span::test_data(),
+                )
+            ),
         }]
     }
 
@@ -251,23 +270,17 @@ fn from_ssv_string_to_value(
     span: Span,
 ) -> Value {
     let rows = string_to_table(s, noheaders, aligned_columns, split_at)
-        .iter()
+        .into_iter()
         .map(|row| {
             let mut dict = IndexMap::new();
             for (col, entry) in row {
-                dict.insert(
-                    col.to_string(),
-                    Value::String {
-                        val: entry.to_string(),
-                        span,
-                    },
-                );
+                dict.insert(col, Value::string(entry, span));
             }
-            Value::from(Spanned { item: dict, span })
+            Value::record(dict.into_iter().collect(), span)
         })
         .collect();
 
-    Value::List { vals: rows, span }
+    Value::list(rows, span)
 }
 
 fn from_ssv(
