@@ -3,7 +3,7 @@ use itertools::Itertools;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span, Spanned, Type,
+    Category, Example, IntoPipelineData, PipelineData, Record, ShellError, Signature, Span, Type,
     Value,
 };
 use serde::de::Deserialize;
@@ -88,35 +88,24 @@ fn convert_yaml_value_to_nu_value(
         val_span,
     );
     Ok(match v {
-        serde_yaml::Value::Bool(b) => Value::Bool { val: *b, span },
-        serde_yaml::Value::Number(n) if n.is_i64() => Value::Int {
-            val: n.as_i64().ok_or(err_not_compatible_number)?,
-            span,
-        },
-        serde_yaml::Value::Number(n) if n.is_f64() => Value::Float {
-            val: n.as_f64().ok_or(err_not_compatible_number)?,
-            span,
-        },
-        serde_yaml::Value::String(s) => Value::String {
-            val: s.to_string(),
-            span,
-        },
+        serde_yaml::Value::Bool(b) => Value::bool(*b, span),
+        serde_yaml::Value::Number(n) if n.is_i64() => {
+            Value::int(n.as_i64().ok_or(err_not_compatible_number)?, span)
+        }
+        serde_yaml::Value::Number(n) if n.is_f64() => {
+            Value::float(n.as_f64().ok_or(err_not_compatible_number)?, span)
+        }
+        serde_yaml::Value::String(s) => Value::string(s.to_string(), span),
         serde_yaml::Value::Sequence(a) => {
             let result: Result<Vec<Value>, ShellError> = a
                 .iter()
                 .map(|x| convert_yaml_value_to_nu_value(x, span, val_span))
                 .collect();
-            Value::List {
-                vals: result?,
-                span,
-            }
+            Value::list(result?, span)
         }
         serde_yaml::Value::Mapping(t) => {
-            let mut collected = Spanned {
-                // Using an IndexMap ensures consistent ordering
-                item: IndexMap::new(),
-                span,
-            };
+            // Using an IndexMap ensures consistent ordering
+            let mut collected = IndexMap::new();
 
             for (k, v) in t {
                 // A ShellError that we re-use multiple times in the Mapping scenario
@@ -128,19 +117,19 @@ fn convert_yaml_value_to_nu_value(
                 );
                 match (k, v) {
                     (serde_yaml::Value::Number(k), _) => {
-                        collected.item.insert(
+                        collected.insert(
                             k.to_string(),
                             convert_yaml_value_to_nu_value(v, span, val_span)?,
                         );
                     }
                     (serde_yaml::Value::Bool(k), _) => {
-                        collected.item.insert(
+                        collected.insert(
                             k.to_string(),
                             convert_yaml_value_to_nu_value(v, span, val_span)?,
                         );
                     }
                     (serde_yaml::Value::String(k), _) => {
-                        collected.item.insert(
+                        collected.insert(
                             k.clone(),
                             convert_yaml_value_to_nu_value(v, span, val_span)?,
                         );
@@ -158,10 +147,7 @@ fn convert_yaml_value_to_nu_value(
                             .first()
                             .and_then(|e| match e {
                                 (serde_yaml::Value::String(s), serde_yaml::Value::Null) => {
-                                    Some(Value::String {
-                                        val: "{{ ".to_owned() + s.as_str() + " }}",
-                                        span,
-                                    })
+                                    Some(Value::string("{{ ".to_owned() + s.as_str() + " }}", span))
                                 }
                                 _ => None,
                             })
@@ -173,26 +159,26 @@ fn convert_yaml_value_to_nu_value(
                 }
             }
 
-            Value::from(collected)
+            Value::record(collected.into_iter().collect(), span)
         }
         serde_yaml::Value::Tagged(t) => {
             let tag = &t.tag;
             let value = match &t.value {
                 serde_yaml::Value::String(s) => {
                     let val = format!("{} {}", tag, s).trim().to_string();
-                    Value::String { val, span }
+                    Value::string(val, span)
                 }
                 serde_yaml::Value::Number(n) => {
                     let val = format!("{} {}", tag, n).trim().to_string();
-                    Value::String { val, span }
+                    Value::string(val, span)
                 }
                 serde_yaml::Value::Bool(b) => {
                     let val = format!("{} {}", tag, b).trim().to_string();
-                    Value::String { val, span }
+                    Value::string(val, span)
                 }
                 serde_yaml::Value::Null => {
                     let val = format!("{}", tag).trim().to_string();
-                    Value::String { val, span }
+                    Value::string(val, span)
                 }
                 v => convert_yaml_value_to_nu_value(v, span, val_span)?,
             };
@@ -226,10 +212,7 @@ pub fn from_yaml_string_to_value(
     match documents.len() {
         0 => Ok(Value::nothing(span)),
         1 => Ok(documents.remove(0)),
-        _ => Ok(Value::List {
-            vals: documents,
-            span,
-        }),
+        _ => Ok(Value::list(documents, span)),
     }
 }
 
@@ -238,33 +221,30 @@ pub fn get_examples() -> Vec<Example<'static>> {
         Example {
             example: "'a: 1' | from yaml",
             description: "Converts yaml formatted string to table",
-            result: Some(Value::Record {
+            result: Some(Value::test_record(Record {
                 cols: vec!["a".to_string()],
                 vals: vec![Value::test_int(1)],
-                span: Span::test_data(),
-            }),
+            })),
         },
         Example {
             example: "'[ a: 1, b: [1, 2] ]' | from yaml",
             description: "Converts yaml formatted string to table",
-            result: Some(Value::List {
-                vals: vec![
-                    Value::Record {
+            result: Some(Value::list(
+                vec![
+                    Value::test_record(Record {
                         cols: vec!["a".to_string()],
                         vals: vec![Value::test_int(1)],
-                        span: Span::test_data(),
-                    },
-                    Value::Record {
+                    }),
+                    Value::test_record(Record {
                         cols: vec!["b".to_string()],
-                        vals: vec![Value::List {
-                            vals: vec![Value::test_int(1), Value::test_int(2)],
-                            span: Span::test_data(),
-                        }],
-                        span: Span::test_data(),
-                    },
+                        vals: vec![Value::list(
+                            vec![Value::test_int(1), Value::test_int(2)],
+                            Span::test_data(),
+                        )],
+                    }),
                 ],
-                span: Span::test_data(),
-            }),
+                Span::test_data(),
+            )),
         },
     ]
 }
@@ -294,20 +274,18 @@ mod test {
             TestCase {
                 description: "Double Curly Braces With Quotes",
                 input: r#"value: "{{ something }}""#,
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["value".to_string()],
                     vals: vec![Value::test_string("{{ something }}")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             TestCase {
                 description: "Double Curly Braces Without Quotes",
                 input: r#"value: {{ something }}"#,
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["value".to_string()],
                     vals: vec![Value::test_string("{{ something }}")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
         ];
         let config = Config::default();
@@ -357,21 +335,19 @@ mod test {
                 Span::test_data(),
             );
 
-            let expected: Result<Value, ShellError> = Ok(Value::List {
-                vals: vec![
-                    Value::Record {
+            let expected: Result<Value, ShellError> = Ok(Value::list(
+                vec![
+                    Value::test_record(Record {
                         cols: vec!["a".to_string(), "b".to_string()],
                         vals: vec![Value::test_string("b"), Value::test_string("c")],
-                        span: Span::test_data(),
-                    },
-                    Value::Record {
+                    }),
+                    Value::test_record(Record {
                         cols: vec!["a".to_string(), "b".to_string()],
                         vals: vec![Value::test_string("g"), Value::test_string("h")],
-                        span: Span::test_data(),
-                    },
+                    }),
                 ],
-                span: Span::test_data(),
-            });
+                Span::test_data(),
+            ));
 
             // Unfortunately the eq function for Value doesn't compare well enough to detect
             // ordering errors in List columns or values.
@@ -388,15 +364,15 @@ mod test {
                 let actual_record = actual_vals[jj].as_record().unwrap();
                 let expected_record = expected_vals[jj].as_record().unwrap();
 
-                let actual_columns = actual_record.0;
-                let expected_columns = expected_record.0;
+                let actual_columns = &actual_record.cols;
+                let expected_columns = &expected_record.cols;
                 assert_eq!(
                     expected_columns, actual_columns,
                     "record {jj}, iteration {ii}"
                 );
 
-                let actual_vals = actual_record.1;
-                let expected_vals = expected_record.1;
+                let actual_vals = &actual_record.vals;
+                let expected_vals = &expected_record.vals;
                 assert_eq!(expected_vals, actual_vals, "record {jj}, iteration {ii}")
             }
         }
@@ -412,43 +388,38 @@ mod test {
         let test_cases: Vec<TestCase> = vec![
             TestCase {
                 input: "Key: !Value ${TEST}-Test-role",
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["Key".to_string()],
                     vals: vec![Value::test_string("!Value ${TEST}-Test-role")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             TestCase {
                 input: "Key: !Value test-${TEST}",
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["Key".to_string()],
                     vals: vec![Value::test_string("!Value test-${TEST}")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             TestCase {
                 input: "Key: !Value",
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["Key".to_string()],
                     vals: vec![Value::test_string("!Value")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             TestCase {
                 input: "Key: !True",
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["Key".to_string()],
                     vals: vec![Value::test_string("!True")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
             TestCase {
                 input: "Key: !123",
-                expected: Ok(Value::Record {
+                expected: Ok(Value::test_record(Record {
                     cols: vec!["Key".to_string()],
                     vals: vec![Value::test_string("!123")],
-                    span: Span::test_data(),
-                }),
+                })),
             },
         ];
 
