@@ -13,7 +13,6 @@ mod formats;
 mod generators;
 mod hash;
 mod help;
-pub mod hook;
 mod math;
 mod misc;
 mod network;
@@ -44,7 +43,6 @@ pub use formats::*;
 pub use generators::*;
 pub use hash::*;
 pub use help::*;
-pub use hook::*;
 pub use math::*;
 pub use misc::*;
 pub use network::*;
