@@ -1,7 +1,9 @@
 use crate::math::utils::run_with_function;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
-use nu_protocol::{Category, Example, PipelineData, ShellError, Signature, Span, Type, Value};
+use nu_protocol::{
+    Category, Example, PipelineData, Record, ShellError, Signature, Span, Type, Value,
+};
 use std::cmp::Ordering;
 use std::collections::HashMap;
 
@@ -80,28 +82,24 @@ impl Command for SubCommand {
             Example {
                 description: "Compute the mode(s) of a list of numbers",
                 example: "[3 3 9 12 12 15] | math mode",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(3), Value::test_int(12)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(3), Value::test_int(12)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Compute the mode(s) of the columns of a table",
                 example: "[{a: 1 b: 3} {a: 2 b: -1} {a: 1 b: 5}] | math mode",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                     cols: vec!["a".to_string(), "b".to_string()],
                     vals: vec![
-                        Value::List {
-                            vals: vec![Value::test_int(1)],
-                            span: Span::test_data(),
-                        },
-                        Value::List {
-                            vals: vec![Value::test_int(-1), Value::test_int(3), Value::test_int(5)],
-                            span: Span::test_data(),
-                        },
+                        Value::list(vec![Value::test_int(1)], Span::test_data()),
+                        Value::list(
+                            vec![Value::test_int(-1), Value::test_int(3), Value::test_int(5)],
+                            Span::test_data(),
+                        ),
                     ],
-                    span: Span::test_data(),
-                }),
+                })),
             },
         ]
     }
@@ -115,9 +113,9 @@ pub fn mode(values: &[Value], _span: Span, head: Span) -> Result<Value, ShellErr
                 return Err(ShellError::OperatorMismatch {
                     op_span: head,
                     lhs_ty: elem[0].get_type().to_string(),
-                    lhs_span: elem[0].span()?,
+                    lhs_span: elem[0].span(),
                     rhs_ty: elem[1].get_type().to_string(),
-                    rhs_span: elem[1].span()?,
+                    rhs_span: elem[1].span(),
                 });
             }
             Ok(elem[0].partial_cmp(&elem[1]).unwrap_or(Ordering::Equal))
@@ -142,12 +140,12 @@ pub fn mode(values: &[Value], _span: Span, head: Span) -> Result<Value, ShellErr
             Value::Filesize { val, .. } => {
                 Ok(HashableType::new(val.to_ne_bytes(), NumberTypes::Filesize))
             }
-            Value::Error { error } => Err(*error.clone()),
+            Value::Error { error, .. } => Err(*error.clone()),
             other => Err(ShellError::UnsupportedInput(
                 "Unable to give a result with this input".to_string(),
                 "value originates from here".into(),
                 head,
-                other.expect_span(),
+                other.span(),
             )),
         })
         .collect::<Result<Vec<HashableType>, ShellError>>()?;
@@ -175,10 +173,7 @@ pub fn mode(values: &[Value], _span: Span, head: Span) -> Result<Value, ShellErr
     }
 
     modes.sort_by(|a, b| a.partial_cmp(b).unwrap_or(Ordering::Equal));
-    Ok(Value::List {
-        vals: modes,
-        span: head,
-    })
+    Ok(Value::list(modes, head))
 }
 
 fn recreate_value(hashable_value: &HashableType, head: Span) -> Value {
@@ -186,14 +181,8 @@ fn recreate_value(hashable_value: &HashableType, head: Span) -> Value {
     match &hashable_value.original_type {
         NumberTypes::Int => Value::int(i64::from_ne_bytes(bytes), head),
         NumberTypes::Float => Value::float(f64::from_ne_bytes(bytes), head),
-        NumberTypes::Duration => Value::Duration {
-            val: i64::from_ne_bytes(bytes),
-            span: head,
-        },
-        NumberTypes::Filesize => Value::Filesize {
-            val: i64::from_ne_bytes(bytes),
-            span: head,
-        },
+        NumberTypes::Duration => Value::duration(i64::from_ne_bytes(bytes), head),
+        NumberTypes::Filesize => Value::filesize(i64::from_ne_bytes(bytes), head),
     }
 }
 
