@@ -64,34 +64,34 @@ impl Command for SubCommand {
             Example {
                 description: "Apply the round function to a list of numbers",
                 example: "[1.5 2.3 -3.1] | math round",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(2), Value::test_int(2), Value::test_int(-3)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(2), Value::test_int(2), Value::test_int(-3)],
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Apply the round function with precision specified",
                 example: "[1.555 2.333 -3.111] | math round -p 2",
-                result: Some(Value::List {
-                    vals: vec![
+                result: Some(Value::list(
+                    vec![
                         Value::test_float(1.56),
                         Value::test_float(2.33),
                         Value::test_float(-3.11),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
             Example {
                 description: "Apply negative precision to a list of numbers",
                 example: "[123, 123.3, -123.4] | math round -p -1",
-                result: Some(Value::List {
-                    vals: vec![
+                result: Some(Value::list(
+                    vec![
                         Value::test_int(120),
                         Value::test_int(120),
                         Value::test_int(-120),
                     ],
-                    span: Span::test_data(),
-                }),
+                    Span::test_data(),
+                )),
             },
         ]
     }
@@ -99,36 +99,32 @@ impl Command for SubCommand {
 
 fn operate(value: Value, head: Span, precision: Option<i64>) -> Value {
     // We treat int values as float values in order to avoid code repetition in the match closure
-    let value = if let Value::Int { val, span } = value {
-        Value::Float {
-            val: val as f64,
-            span,
-        }
+    let span = value.span();
+    let value = if let Value::Int { val, .. } = value {
+        Value::float(val as f64, span)
     } else {
         value
     };
 
     match value {
-        Value::Float { val, span } => match precision {
-            Some(precision_number) => Value::Float {
-                val: ((val * ((10_f64).powf(precision_number as f64))).round()
-                    / (10_f64).powf(precision_number as f64)),
+        Value::Float { val, .. } => match precision {
+            Some(precision_number) => Value::float(
+                (val * ((10_f64).powf(precision_number as f64))).round()
+                    / (10_f64).powf(precision_number as f64),
                 span,
-            },
-            None => Value::Int {
-                val: val.round() as i64,
-                span,
-            },
+            ),
+            None => Value::int(val.round() as i64, span),
         },
         Value::Error { .. } => value,
-        other => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        other => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "numeric".into(),
                 wrong_type: other.get_type().to_string(),
                 dst_span: head,
-                src_span: other.expect_span(),
-            }),
-        },
+                src_span: other.span(),
+            },
+            head,
+        ),
     }
 }
 
