@@ -1,6 +1,6 @@
 use indexmap::map::IndexMap;
 use nu_protocol::ast::Call;
-use nu_protocol::{IntoPipelineData, PipelineData, ShellError, Span, Spanned, Value};
+use nu_protocol::{IntoPipelineData, PipelineData, Record, ShellError, Span, Value};
 
 pub fn run_with_function(
     call: &Call,
@@ -26,18 +26,18 @@ fn helper_for_tables(
     let mut column_values = IndexMap::new();
     for val in values {
         match val {
-            Value::Record { cols, vals, .. } => {
-                for (key, value) in cols.iter().zip(vals.iter()) {
+            Value::Record { val, .. } => {
+                for (key, value) in val {
                     column_values
                         .entry(key.clone())
                         .and_modify(|v: &mut Vec<Value>| v.push(value.clone()))
                         .or_insert_with(|| vec![value.clone()]);
                 }
             }
-            Value::Error { error } => return Err(*error.clone()),
+            Value::Error { error, .. } => return Err(*error.clone()),
             _ => {
                 //Turns out we are not dealing with a table
-                return mf(values, val.expect_span(), name);
+                return mf(values, val.span(), name);
             }
         }
     }
@@ -57,10 +57,7 @@ fn helper_for_tables(
         ));
     }
 
-    Ok(Value::from(Spanned {
-        item: column_totals,
-        span: name,
-    }))
+    Ok(Value::record(column_totals.into_iter().collect(), name))
 }
 
 pub fn calculate(
@@ -74,7 +71,7 @@ pub fn calculate(
         PipelineData::ListStream(s, ..) => {
             helper_for_tables(&s.collect::<Vec<Value>>(), span, name, mf)
         }
-        PipelineData::Value(Value::List { ref vals, span }, ..) => match &vals[..] {
+        PipelineData::Value(Value::List { ref vals, .. }, ..) => match &vals[..] {
             [Value::Record { .. }, _end @ ..] => helper_for_tables(
                 vals,
                 values.span().expect("PipelineData::Value had no span"),
@@ -83,19 +80,24 @@ pub fn calculate(
             ),
             _ => mf(vals, span, name),
         },
-        PipelineData::Value(Value::Record { vals, cols, span }, ..) => {
-            let new_vals: Result<Vec<Value>, ShellError> =
-                vals.into_iter().map(|val| mf(&[val], span, name)).collect();
+        PipelineData::Value(Value::Record { val: record, .. }, ..) => {
+            let new_vals: Result<Vec<Value>, ShellError> = record
+                .vals
+                .into_iter()
+                .map(|val| mf(&[val], span, name))
+                .collect();
             match new_vals {
-                Ok(vec) => Ok(Value::Record {
-                    cols,
-                    vals: vec,
+                Ok(vec) => Ok(Value::record(
+                    Record {
+                        cols: record.cols,
+                        vals: vec,
+                    },
                     span,
-                }),
+                )),
                 Err(err) => Err(err),
             }
         }
-        PipelineData::Value(Value::Range { val, span, .. }, ..) => {
+        PipelineData::Value(Value::Range { val, .. }, ..) => {
             let new_vals: Result<Vec<Value>, ShellError> = val
                 .into_range_iter(None)?
                 .map(|val| mf(&[val], span, name))
