@@ -91,28 +91,26 @@ impl Command for SubCommand {
 
         let output: Result<String, ShellError> = input
             .into_iter()
-            .map(move |value| match value {
-                Value::Record {
-                    ref cols,
-                    ref vals,
-                    span,
-                } => {
-                    let url_components = cols
-                        .iter()
-                        .zip(vals.iter())
-                        .try_fold(UrlComponents::new(), |url, (k, v)| {
-                            url.add_component(k.clone(), v.clone(), span)
-                        });
+            .map(move |value| {
+                let span = value.span();
+                match value {
+                    Value::Record { val, .. } => {
+                        let url_components = val
+                            .into_iter()
+                            .try_fold(UrlComponents::new(), |url, (k, v)| {
+                                url.add_component(k, v, span)
+                            });
 
-                    url_components?.to_url(span)
+                        url_components?.to_url(span)
+                    }
+                    Value::Error { error, .. } => Err(*error),
+                    other => Err(ShellError::UnsupportedInput(
+                        "Expected a record from pipeline".to_string(),
+                        "value originates from here".into(),
+                        head,
+                        other.span(),
+                    )),
                 }
-                Value::Error { error } => Err(*error),
-                other => Err(ShellError::UnsupportedInput(
-                    "Expected a record from pipeline".to_string(),
-                    "value originates from here".into(),
-                    head,
-                    other.expect_span(),
-                )),
             })
             .collect();
 
@@ -140,9 +138,10 @@ impl UrlComponents {
     }
 
     pub fn add_component(self, key: String, value: Value, _span: Span) -> Result<Self, ShellError> {
+        let span = value.span();
         if key == "port" {
             return match value {
-                Value::String { val, span } => {
+                Value::String { val, .. } => {
                     if val.trim().is_empty() {
                         Ok(self)
                     } else {
@@ -160,30 +159,25 @@ impl UrlComponents {
                         }
                     }
                 }
-                Value::Int { val, span: _ } => Ok(Self {
+                Value::Int { val, .. } => Ok(Self {
                     port: Some(val),
                     ..self
                 }),
-                Value::Error { error } => Err(*error),
+                Value::Error { error, .. } => Err(*error),
                 other => Err(ShellError::IncompatibleParametersSingle {
                     msg: String::from(
                         "Port parameter should be an unsigned integer or a string representing it",
                     ),
-                    span: other.expect_span(),
+                    span: other.span(),
                 }),
             };
         }
 
         if key == "params" {
             return match value {
-                Value::Record {
-                    ref cols,
-                    ref vals,
-                    span,
-                } => {
-                    let mut qs = cols
+                Value::Record { ref val, .. } => {
+                    let mut qs = val
                         .iter()
-                        .zip(vals.iter())
                         .map(|(k, v)| match v.as_string() {
                             Ok(val) => Ok(format!("{k}={val}")),
                             Err(err) => Err(err),
@@ -202,7 +196,7 @@ impl UrlComponents {
                             // if query is present it means that also query_span is set.
                             return Err(ShellError::IncompatibleParameters {
                                 left_message: format!("Mismatch, qs from params is: {qs}"),
-                                left_span: value.expect_span(),
+                                left_span: value.span(),
                                 right_message: format!("instead query is: {q}"),
                                 right_span: self.query_span.unwrap_or(Span::unknown()),
                             });
@@ -215,10 +209,10 @@ impl UrlComponents {
                         ..self
                     })
                 }
-                Value::Error { error } => Err(*error),
+                Value::Error { error, .. } => Err(*error),
                 other => Err(ShellError::IncompatibleParametersSingle {
                     msg: String::from("Key params has to be a record"),
-                    span: other.expect_span(),
+                    span: other.span(),
                 }),
             };
         }
@@ -260,7 +254,7 @@ impl UrlComponents {
                                     // if query is present it means that also params_span is set.
                                     return Err(ShellError::IncompatibleParameters {
                                         left_message: format!("Mismatch, query param is: {s}"),
-                                        left_span: value.expect_span(),
+                                        left_span: value.span(),
                                         right_message: format!("instead qs from params is: {q}"),
                                         right_span: self.params_span.unwrap_or(Span::unknown()),
                                     });
@@ -269,7 +263,7 @@ impl UrlComponents {
 
                             Ok(Self {
                                 query: Some(format!("?{s}")),
-                                query_span: Some(value.expect_span()),
+                                query_span: Some(value.span()),
                                 ..self
                             })
                         }
