@@ -7,7 +7,8 @@ use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, IntoPipelineData, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    record, Category, Example, IntoPipelineData, PipelineData, ShellError, Signature, Span,
+    SyntaxShape, Type, Value,
 };
 use num_traits::AsPrimitive;
 use std::io::stdout;
@@ -68,7 +69,13 @@ There are 4 `key_type` variants:
     media - dedicated media keys (play, pause, tracknext ...)
     other - keys not falling under previous categories (up, down, backspace, enter ...)"#
     }
-
+    fn examples(&self) -> Vec<Example> {
+        vec![Example {
+            description: "Listen for a keyboard shortcut and find out how nu receives it",
+            example: "input listen --types [key]",
+            result: None,
+        }]
+    }
     fn run(
         &self,
         engine_state: &EngineState,
@@ -150,7 +157,8 @@ impl EventTypeFilter {
         if let Value::List { vals, .. } = value {
             let mut filter = Self::none();
             for event_type in vals {
-                if let Value::String { val, span } = event_type {
+                let span = event_type.span();
+                if let Value::String { val, .. } = event_type {
                     match val.as_str() {
                         "focus" => filter.listen_focus = true,
                         "key" => filter.listen_key = true,
@@ -183,7 +191,7 @@ impl EventTypeFilter {
             "--types expects a list of strings".to_string(),
             "value originates from here".into(),
             head,
-            value.span().unwrap_or(head),
+            value.span(),
         )
     }
 
@@ -273,13 +281,13 @@ fn create_focus_event(
     event_type: FocusEventType,
 ) -> Option<Value> {
     if filter.listen_focus {
-        let cols = vec!["type".to_string(), "event".to_string()];
-        let vals = vec![
-            Value::string("focus", head),
-            Value::string(event_type.string(), head),
-        ];
-
-        Some(Value::record(cols, vals, head))
+        Some(Value::record(
+            record! {
+                "type" => Value::string("focus", head),
+                "event" => Value::string(event_type.string(), head)
+            },
+            head,
+        ))
     } else {
         None
     }
@@ -308,28 +316,26 @@ fn create_key_event(
             return None;
         }
 
-        let mut cols = vec![
-            "type".to_string(),
-            "key_type".to_string(),
-            "code".to_string(),
-            "modifiers".to_string(),
-        ];
-
-        let typ = Value::string("key".to_string(), head);
         let (key, code) = get_keycode_name(head, raw_code);
-        let modifiers = parse_modifiers(head, raw_modifiers);
-        let mut vals = vec![typ, key, code, modifiers];
+
+        let mut record = record! {
+            "type" => Value::string("key", head),
+            "key_type" => key,
+            "code" => code,
+            "modifiers" => parse_modifiers(head, raw_modifiers),
+        };
 
         if add_raw {
             if let KeyCode::Char(c) = raw_code {
-                cols.push("raw_code".to_string());
-                vals.push(Value::int(c.as_(), head));
+                record.push("raw_code", Value::int(c.as_(), head));
             }
-            cols.push("raw_modifiers".to_string());
-            vals.push(Value::int(raw_modifiers.bits() as i64, head));
+            record.push(
+                "raw_modifiers",
+                Value::int(raw_modifiers.bits() as i64, head),
+            );
         }
 
-        Some(Value::record(cols, vals, head))
+        Some(Value::record(record, head))
     } else {
         None
     }
@@ -373,18 +379,6 @@ fn create_mouse_event(
     add_raw: bool,
 ) -> Option<Value> {
     if filter.listen_mouse {
-        let mut cols = vec![
-            "type".to_string(),
-            "col".to_string(),
-            "row".to_string(),
-            "kind".to_string(),
-            "modifiers".to_string(),
-        ];
-
-        let typ = Value::string("mouse".to_string(), head);
-        let col = Value::int(event.column as i64, head);
-        let row = Value::int(event.row as i64, head);
-
         let kind = match event.kind {
             MouseEventKind::Down(btn) => format!("{btn:?}_down"),
             MouseEventKind::Up(btn) => format!("{btn:?}_up"),
@@ -392,18 +386,26 @@ fn create_mouse_event(
             MouseEventKind::Moved => "moved".to_string(),
             MouseEventKind::ScrollDown => "scroll_down".to_string(),
             MouseEventKind::ScrollUp => "scroll_up".to_string(),
+            MouseEventKind::ScrollLeft => "scroll_left".to_string(),
+            MouseEventKind::ScrollRight => "scroll_right".to_string(),
         };
-        let kind = Value::string(kind, head);
-        let modifiers = parse_modifiers(head, &event.modifiers);
 
-        let mut vals = vec![typ, col, row, kind, modifiers];
+        let mut record = record! {
+            "type" => Value::string("mouse", head),
+            "col" => Value::int(event.column as i64, head),
+            "row" => Value::int(event.row as i64, head),
+            "kind" => Value::string(kind, head),
+            "modifiers" => parse_modifiers(head, &event.modifiers),
+        };
 
         if add_raw {
-            cols.push("raw_modifiers".to_string());
-            vals.push(Value::int(event.modifiers.bits() as i64, head));
+            record.push(
+                "raw_modifiers",
+                Value::int(event.modifiers.bits() as i64, head),
+            );
         }
 
-        Some(Value::record(cols, vals, head))
+        Some(Value::record(record, head))
     } else {
         None
     }
@@ -411,10 +413,12 @@ fn create_mouse_event(
 
 fn create_paste_event(head: Span, filter: &EventTypeFilter, content: &str) -> Option<Value> {
     if filter.listen_paste {
-        let cols = vec!["type".to_string(), "content".to_string()];
-        let vals = vec![Value::string("paste", head), Value::string(content, head)];
+        let record = record! {
+            "type" => Value::string("paste", head),
+            "content" => Value::string(content, head),
+        };
 
-        Some(Value::record(cols, vals, head))
+        Some(Value::record(record, head))
     } else {
         None
     }
@@ -427,14 +431,13 @@ fn create_resize_event(
     rows: u16,
 ) -> Option<Value> {
     if filter.listen_resize {
-        let cols = vec!["type".to_string(), "col".to_string(), "row".to_string()];
-        let vals = vec![
-            Value::string("resize", head),
-            Value::int(columns as i64, head),
-            Value::int(rows as i64, head),
-        ];
+        let record = record! {
+            "type" => Value::string("resize", head),
+            "col" => Value::int(columns as i64, head),
+            "row" => Value::int(rows as i64, head),
+        };
 
-        Some(Value::record(cols, vals, head))
+        Some(Value::record(record, head))
     } else {
         None
     }
