@@ -2,6 +2,7 @@ mod bool;
 mod chars;
 mod decimal;
 mod dice;
+mod float;
 mod integer;
 mod random_;
 mod uuid;
@@ -10,6 +11,7 @@ pub use self::bool::SubCommand as RandomBool;
 pub use self::chars::SubCommand as RandomChars;
 pub use self::decimal::SubCommand as RandomDecimal;
 pub use self::dice::SubCommand as RandomDice;
+pub use self::float::SubCommand as RandomFloat;
 pub use self::integer::SubCommand as RandomInteger;
 pub use self::uuid::SubCommand as RandomUuid;
 pub use random_::RandomCommand as Random;
