@@ -3,7 +3,7 @@ use nu_cmd_base::input_handler::{operate, CmdArgument};
 use nu_engine::CallExt;
 use nu_protocol::ast::Call;
 use nu_protocol::ast::CellPath;
-use nu_protocol::engine::{Command, EngineState, Stack};
+use nu_protocol::engine::{Command, EngineState, Stack, StateWorkingSet};
 use nu_protocol::Category;
 use nu_protocol::{Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value};
 use unicode_segmentation::UnicodeSegmentation;
@@ -62,6 +62,10 @@ impl Command for SubCommand {
         vec!["size", "count"]
     }
 
+    fn is_const(&self) -> bool {
+        true
+    }
+
     fn run(
         &self,
         engine_state: &EngineState,
@@ -70,11 +74,17 @@ impl Command for SubCommand {
         input: PipelineData,
     ) -> Result<PipelineData, ShellError> {
         let cell_paths: Vec<CellPath> = call.rest(engine_state, stack, 0)?;
-        let args = Arguments {
-            cell_paths: (!cell_paths.is_empty()).then_some(cell_paths),
-            graphemes: grapheme_flags(call)?,
-        };
-        operate(action, args, input, call.head, engine_state.ctrlc.clone())
+        run(cell_paths, engine_state, call, input)
+    }
+
+    fn run_const(
+        &self,
+        working_set: &StateWorkingSet,
+        call: &Call,
+        input: PipelineData,
+    ) -> Result<PipelineData, ShellError> {
+        let cell_paths: Vec<CellPath> = call.rest_const(working_set, 0)?;
+        run(cell_paths, working_set.permanent(), call, input)
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -92,15 +102,28 @@ impl Command for SubCommand {
             Example {
                 description: "Return the lengths of multiple strings",
                 example: "['hi' 'there'] | str length",
-                result: Some(Value::List {
-                    vals: vec![Value::test_int(2), Value::test_int(5)],
-                    span: Span::test_data(),
-                }),
+                result: Some(Value::list(
+                    vec![Value::test_int(2), Value::test_int(5)],
+                    Span::test_data(),
+                )),
             },
         ]
     }
 }
 
+fn run(
+    cell_paths: Vec<CellPath>,
+    engine_state: &EngineState,
+    call: &Call,
+    input: PipelineData,
+) -> Result<PipelineData, ShellError> {
+    let args = Arguments {
+        cell_paths: (!cell_paths.is_empty()).then_some(cell_paths),
+        graphemes: grapheme_flags(call)?,
+    };
+    operate(action, args, input, call.head, engine_state.ctrlc.clone())
+}
+
 fn action(input: &Value, arg: &Arguments, head: Span) -> Value {
     match input {
         Value::String { val, .. } => Value::int(
@@ -112,14 +135,15 @@ fn action(input: &Value, arg: &Arguments, head: Span) -> Value {
             head,
         ),
         Value::Error { .. } => input.clone(),
-        _ => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        _ => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "string".into(),
                 wrong_type: input.get_type().to_string(),
                 dst_span: head,
-                src_span: input.expect_span(),
-            }),
-        },
+                src_span: input.span(),
+            },
+            head,
+        ),
     }
 }
 
@@ -129,10 +153,7 @@ mod test {
 
     #[test]
     fn use_utf8_bytes() {
-        let word = Value::String {
-            val: String::from("🇯🇵ほげ ふが ぴよ"),
-            span: Span::test_data(),
-        };
+        let word = Value::string(String::from("🇯🇵ほげ ふが ぴよ"), Span::test_data());
 
         let options = Arguments {
             cell_paths: None,
