@@ -4,8 +4,8 @@ use nu_engine::CallExt;
 use nu_protocol::{
     ast::{Call, CellPath},
     engine::{Command, EngineState, Stack},
-    report_error_new, Category, Example, PipelineData, ShellError, Signature, Span, Spanned,
-    SyntaxShape, Type, Value,
+    Category, Example, PipelineData, Record, ShellError, Signature, Span, Spanned, SyntaxShape,
+    Type, Value,
 };
 
 struct Arguments {
@@ -36,7 +36,7 @@ impl Command for SubCommand {
         Signature::build("str replace")
             .input_output_types(vec![
                 (Type::String, Type::String),
-                // TODO: clarify behavior with cellpath-rest argument
+                // TODO: clarify behavior with cell-path-rest argument
                 (Type::Table(vec![]), Type::Table(vec![])),
                 (Type::Record(vec![]), Type::Record(vec![])),
                 (
@@ -57,11 +57,6 @@ impl Command for SubCommand {
                 "do not expand capture groups (like $name) in the replacement string",
                 Some('n'),
             )
-            .switch(
-                "string",
-                "DEPRECATED option, will be removed in 0.85. Substring matching is now the default.",
-                Some('s'),
-            )
             .switch(
                 "regex",
                 "match the pattern as a regular expression in the input, instead of a substring",
@@ -96,18 +91,6 @@ impl Command for SubCommand {
         let cell_paths: Vec<CellPath> = call.rest(engine_state, stack, 2)?;
         let cell_paths = (!cell_paths.is_empty()).then_some(cell_paths);
         let literal_replace = call.has_flag("no-expand");
-        if call.has_flag("string") {
-            report_error_new(
-                engine_state,
-                &ShellError::GenericError(
-                    "Deprecated option".into(),
-                    "`str replace --string` is deprecated and will be removed in 0.85.".into(),
-                    Some(call.head),
-                    Some("Substring matching is now the default. Use `--regex` or `--multiline` for matching regular expressions.".into()),
-                    vec![],
-                ),
-            );
-        }
         let no_regex = !call.has_flag("regex") && !call.has_flag("multiline");
         let multiline = call.has_flag("multiline");
 
@@ -149,32 +132,30 @@ impl Command for SubCommand {
                 description: "Find and replace all occurrences of find string in table using regular expression",
                 example:
                     "[[ColA ColB ColC]; [abc abc ads]] | str replace -ar 'b' 'z' ColA ColC",
-                result: Some(Value::List {
-                    vals: vec![Value::Record {
+                result: Some(Value::list (
+                    vec![Value::test_record(Record {
                         cols: vec!["ColA".to_string(), "ColB".to_string(), "ColC".to_string()],
                         vals: vec![
                             Value::test_string("azc"),
                             Value::test_string("abc"),
                             Value::test_string("ads"),
                         ],
-                        span: Span::test_data(),
-                    }],
-                    span: Span::test_data(),
-                }),
+                    })],
+                     Span::test_data(),
+                )),
             },
             Example {
                 description: "Find and replace all occurrences of find string in record using regular expression",
                 example:
                     "{ KeyA: abc, KeyB: abc, KeyC: ads } | str replace -ar 'b' 'z' KeyA KeyC",
-                result: Some(Value::Record {
+                result: Some(Value::test_record(Record {
                         cols: vec!["KeyA".to_string(), "KeyB".to_string(), "KeyC".to_string()],
                         vals: vec![
                             Value::test_string("azc"),
                             Value::test_string("abc"),
                             Value::test_string("ads"),
                         ],
-                        span: Span::test_data(),
-                    }),
+                    })),
             },
             Example {
                 description: "Find and replace contents without using the replace parameter as a regular expression",
@@ -227,15 +208,9 @@ fn action(
             if *no_regex {
                 // just use regular string replacement vs regular expressions
                 if *all {
-                    Value::String {
-                        val: val.replace(find_str, replace_str),
-                        span: head,
-                    }
+                    Value::string(val.replace(find_str, replace_str), head)
                 } else {
-                    Value::String {
-                        val: val.replacen(find_str, replace_str, 1),
-                        span: head,
-                    }
+                    Value::string(val.replacen(find_str, replace_str, 1), head)
                 }
             } else {
                 // use regular expressions to replace strings
@@ -249,48 +224,50 @@ fn action(
                 match regex {
                     Ok(re) => {
                         if *all {
-                            Value::String {
-                                val: {
+                            Value::string(
+                                {
                                     if *literal_replace {
                                         re.replace_all(val, NoExpand(replace_str)).to_string()
                                     } else {
                                         re.replace_all(val, replace_str).to_string()
                                     }
                                 },
-                                span: head,
-                            }
+                                head,
+                            )
                         } else {
-                            Value::String {
-                                val: {
+                            Value::string(
+                                {
                                     if *literal_replace {
                                         re.replace(val, NoExpand(replace_str)).to_string()
                                     } else {
                                         re.replace(val, replace_str).to_string()
                                     }
                                 },
-                                span: head,
-                            }
+                                head,
+                            )
                         }
                     }
-                    Err(e) => Value::Error {
-                        error: Box::new(ShellError::IncorrectValue {
+                    Err(e) => Value::error(
+                        ShellError::IncorrectValue {
                             msg: format!("Regex error: {e}"),
                             val_span: find.span,
                             call_span: head,
-                        }),
-                    },
+                        },
+                        find.span,
+                    ),
                 }
             }
         }
         Value::Error { .. } => input.clone(),
-        _ => Value::Error {
-            error: Box::new(ShellError::OnlySupportsThisInputType {
+        _ => Value::error(
+            ShellError::OnlySupportsThisInputType {
                 exp_input_type: "string".into(),
                 wrong_type: input.get_type().to_string(),
                 dst_span: head,
-                src_span: input.expect_span(),
-            }),
-        },
+                src_span: input.span(),
+            },
+            head,
+        ),
     }
 }
 
