@@ -2,8 +2,8 @@ use nu_engine::CallExt;
 use nu_protocol::{
     ast::Call,
     engine::{Command, EngineState, Stack},
-    Category, Example, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData, ShellError,
-    Signature, Span, Spanned, SyntaxShape, Type, Value,
+    record, Category, Example, IntoInterruptiblePipelineData, IntoPipelineData, PipelineData,
+    ShellError, Signature, Span, Spanned, SyntaxShape, Type, Value,
 };
 use winreg::{enums::*, RegKey};
 
@@ -120,15 +120,14 @@ fn registry_query(
         let mut reg_values = vec![];
         for (name, val) in reg_key.enum_values().flatten() {
             let (nu_value, reg_type) = reg_value_to_nu_value(val, call_span);
-            reg_values.push(Value::Record {
-                cols: vec!["name".to_string(), "value".to_string(), "type".to_string()],
-                vals: vec![
-                    Value::string(name, call_span),
-                    nu_value,
-                    Value::string(format!("{:?}", reg_type), call_span),
-                ],
-                span: *registry_key_span,
-            })
+            reg_values.push(Value::record(
+                record! {
+                    "name" => Value::string(name, call_span),
+                    "value" => nu_value,
+                    "type" => Value::string(format!("{:?}", reg_type), call_span),
+                },
+                *registry_key_span,
+            ))
         }
         Ok(reg_values.into_pipeline_data(engine_state.ctrlc.clone()))
     } else {
@@ -138,15 +137,14 @@ fn registry_query(
                 match reg_value {
                     Ok(val) => {
                         let (nu_value, reg_type) = reg_value_to_nu_value(val, call_span);
-                        Ok(Value::Record {
-                            cols: vec!["name".to_string(), "value".to_string(), "type".to_string()],
-                            vals: vec![
-                                Value::string(value.item, call_span),
-                                nu_value,
-                                Value::string(format!("{:?}", reg_type), call_span),
-                            ],
-                            span: value.span,
-                        }
+                        Ok(Value::record(
+                            record! {
+                                "name" => Value::string(value.item, call_span),
+                                "value" => nu_value,
+                                "type" => Value::string(format!("{:?}", reg_type), call_span),
+                            },
+                            value.span,
+                        )
                         .into_pipeline_data())
                     }
                     Err(_) => Err(ShellError::GenericError(
