@@ -110,11 +110,11 @@ prints out the list properly."#
                     Ok(PipelineData::empty())
                 }
             }
-            PipelineData::Value(Value::Record { cols, vals, .. }, ..) => {
+            PipelineData::Value(Value::Record { val, .. }, ..) => {
                 // dbg!("value::record");
                 let mut items = vec![];
 
-                for (i, (c, v)) in cols.into_iter().zip(vals).enumerate() {
+                for (i, (c, v)) in val.into_iter().enumerate() {
                     items.push((i, c, v.into_string(", ", config)))
                 }
 
@@ -243,10 +243,7 @@ fn create_grid_output(
         if let Some(grid_display) = grid.fit_into_width(cols as usize) {
             Value::string(grid_display.to_string(), call.head)
         } else {
-            Value::String {
-                val: format!("Couldn't fit grid into {cols} columns!"),
-                span: call.head,
-            }
+            Value::string(format!("Couldn't fit grid into {cols} columns!"), call.head)
         }
         .into_pipeline_data(),
     )
