@@ -2,8 +2,7 @@ use nu_test_support::{nu, pipeline};
 
 #[test]
 fn median_numbers_with_even_rows() {
-    let actual = nu!(
-        cwd: ".", pipeline(
+    let actual = nu!(pipeline(
         r#"
              echo [10 6 19 21 4]
              | math median
@@ -15,8 +14,7 @@ fn median_numbers_with_even_rows() {
 
 #[test]
 fn median_numbers_with_odd_rows() {
-    let actual = nu!(
-        cwd: ".", pipeline(
+    let actual = nu!(pipeline(
         r#"
              echo [3 8 9 12 12 15]
              | math median
@@ -28,8 +26,7 @@ fn median_numbers_with_odd_rows() {
 
 #[test]
 fn median_mixed_numbers() {
-    let actual = nu!(
-        cwd: ".", pipeline(
+    let actual = nu!(pipeline(
         r#"
              echo [-11.5 -13.5 10]
              | math median
