@@ -8,6 +8,7 @@ mod cal;
 mod cd;
 mod compact;
 mod continue_;
+mod conversions;
 mod cp;
 mod date;
 mod def;
@@ -99,6 +100,7 @@ mod to_text;
 mod touch;
 mod transpose;
 mod try_;
+mod ucp;
 mod uniq;
 mod uniq_by;
 mod update;
