@@ -20,21 +20,6 @@ fn doesnt_convert_record_to_table() {
     assert_eq!(actual.out, "{a: 2}");
 }
 
-#[cfg(features = "inc")]
-#[test]
-fn sets_the_column_from_a_block_run_output() {
-    let actual = nu!(
-        cwd: "tests/fixtures/formats", pipeline(
-        "
-            open cargo_sample.toml
-            | upsert dev-dependencies.pretty_assertions { open cargo_sample.toml | get dev-dependencies.pretty_assertions | inc --minor }
-            | get dev-dependencies.pretty_assertions
-        "
-    ));
-
-    assert_eq!(actual.out, "0.7.0");
-}
-
 #[test]
 fn sets_the_column_from_a_block_full_stream_output() {
     let actual = nu!(
