@@ -4,11 +4,11 @@ use std::collections::HashSet;
 pub fn get_columns(input: &[Value]) -> Vec<String> {
     let mut columns = vec![];
     for item in input {
-        let Value::Record { cols, .. } = item else {
+        let Value::Record { val, .. } = item else {
             return vec![];
         };
 
-        for col in cols {
+        for col in &val.cols {
             if !columns.contains(col) {
                 columns.push(col.to_string());
             }
@@ -19,10 +19,10 @@ pub fn get_columns(input: &[Value]) -> Vec<String> {
 }
 
 // If a column doesn't exist in the input, return it.
-pub fn nonexistent_column(inputs: Vec<String>, columns: Vec<String>) -> Option<String> {
+pub fn nonexistent_column(inputs: &[String], columns: &[String]) -> Option<String> {
     let set: HashSet<String> = HashSet::from_iter(columns.iter().cloned());
 
-    for input in &inputs {
+    for input in inputs {
         if set.contains(input) {
             continue;
         }
