@@ -4,7 +4,7 @@ use std::io::{self, Result};
 use crossterm::event::KeyEvent;
 use nu_protocol::{
     engine::{EngineState, Stack},
-    Value,
+    record, Record, Value,
 };
 use ratatui::layout::Rect;
 
@@ -104,10 +104,6 @@ impl ViewCommand for HelpCmd {
         })
     }
 
-    fn display_config_option(&mut self, _: String, _: String, _: String) -> bool {
-        false
-    }
-
     fn parse(&mut self, args: &str) -> Result<()> {
         self.input_command = args.trim().to_owned();
 
@@ -169,17 +165,10 @@ fn help_frame_data(
 
             let (cols, mut vals) = help_manual_data(manual, aliases);
             let vals = vals.remove(0);
-            Value::Record {
-                cols,
-                vals,
-                span: NuSpan::unknown(),
-            }
+            Value::record(Record { cols, vals }, NuSpan::unknown())
         })
         .collect();
-    let commands = Value::List {
-        vals: commands,
-        span: NuSpan::unknown(),
-    };
+    let commands = Value::list(commands, NuSpan::unknown());
 
     collect_input(commands)
 }
@@ -192,49 +181,49 @@ fn help_manual_data(manual: &HelpManual, aliases: &[String]) -> (Vec<String>, Ve
     let arguments = manual
         .arguments
         .iter()
-        .map(|e| Value::Record {
-            cols: vec![String::from("example"), String::from("description")],
-            vals: vec![nu_str(&e.example), nu_str(&e.description)],
-            span: NuSpan::unknown(),
+        .map(|e| {
+            Value::record(
+                record! {
+                    "example" => nu_str(&e.example),
+                    "description" => nu_str(&e.description),
+                },
+                NuSpan::unknown(),
+            )
         })
         .collect();
 
-    let arguments = Value::List {
-        vals: arguments,
-        span: NuSpan::unknown(),
-    };
+    let arguments = Value::list(arguments, NuSpan::unknown());
 
     let examples = manual
         .examples
         .iter()
-        .map(|e| Value::Record {
-            cols: vec![String::from("example"), String::from("description")],
-            vals: vec![nu_str(&e.example), nu_str(&e.description)],
-            span: NuSpan::unknown(),
+        .map(|e| {
+            Value::record(
+                record! {
+                    "example" => nu_str(&e.example),
+                    "description" => nu_str(&e.description),
+                },
+                NuSpan::unknown(),
+            )
         })
         .collect();
-    let examples = Value::List {
-        vals: examples,
-        span: NuSpan::unknown(),
-    };
+    let examples = Value::list(examples, NuSpan::unknown());
 
     let inputs = manual
         .input
         .iter()
-        .map(|e| Value::Record {
-            cols: vec![
-                String::from("name"),
-                String::from("context"),
-                String::from("description"),
-            ],
-            vals: vec![nu_str(&e.code), nu_str(&e.context), nu_str(&e.description)],
-            span: NuSpan::unknown(),
+        .map(|e| {
+            Value::record(
+                record! {
+                    "name" => nu_str(&e.code),
+                    "context" => nu_str(&e.context),
+                    "description" => nu_str(&e.description),
+                },
+                NuSpan::unknown(),
+            )
         })
         .collect();
-    let inputs = Value::List {
-        vals: inputs,
-        span: NuSpan::unknown(),
-    };
+    let inputs = Value::list(inputs, NuSpan::unknown());
 
     let configuration = manual
         .config_options
@@ -243,38 +232,30 @@ fn help_manual_data(manual: &HelpManual, aliases: &[String]) -> (Vec<String>, Ve
             let values = o
                 .values
                 .iter()
-                .map(|v| Value::Record {
-                    cols: vec![String::from("example"), String::from("description")],
-                    vals: vec![nu_str(&v.example), nu_str(&v.description)],
-                    span: NuSpan::unknown(),
+                .map(|v| {
+                    Value::record(
+                        record! {
+                            "example" => nu_str(&v.example),
+                            "description" => nu_str(&v.description),
+                        },
+                        NuSpan::unknown(),
+                    )
                 })
                 .collect();
-            let values = Value::List {
-                vals: values,
-                span: NuSpan::unknown(),
-            };
+            let values = Value::list(values, NuSpan::unknown());
 
-            Value::Record {
-                cols: vec![
-                    String::from("name"),
-                    String::from("context"),
-                    String::from("description"),
-                    String::from("values"),
-                ],
-                vals: vec![
-                    nu_str(&o.group),
-                    nu_str(&o.key),
-                    nu_str(&o.description),
-                    values,
-                ],
-                span: NuSpan::unknown(),
-            }
+            Value::record(
+                record! {
+                    "name" => nu_str(&o.group),
+                    "context" => nu_str(&o.key),
+                    "description" => nu_str(&o.description),
+                    "values" => values,
+                },
+                NuSpan::unknown(),
+            )
         })
         .collect();
-    let configuration = Value::List {
-        vals: configuration,
-        span: NuSpan::unknown(),
-    };
+    let configuration = Value::list(configuration, NuSpan::unknown());
 
     let name = nu_str(&manual.name);
     let aliases = nu_str(&aliases.join(", "));
