@@ -77,9 +77,6 @@ impl Command for Explore {
         update_config(&mut config, show_index, show_head);
         prepare_default_config(&mut config);
 
-        let show_banner = is_need_banner(&config).unwrap_or(true);
-        let exit_esc = is_need_esc_exit(&config).unwrap_or(true);
-
         let style = style_from_config(&config);
 
         let lscolors = create_lscolors(engine_state, stack);
@@ -89,8 +86,6 @@ impl Command for Explore {
         config.reverse = is_reverse;
         config.peek_value = peek_value;
         config.reverse = is_reverse;
-        config.exit_esc = exit_esc;
-        config.show_banner = show_banner;
 
         let result = run_pager(engine_state, &mut stack.clone(), ctrlc, input, config);
 
@@ -98,9 +93,7 @@ impl Command for Explore {
             Ok(Some(value)) => Ok(PipelineData::Value(value, None)),
             Ok(None) => Ok(PipelineData::Value(Value::default(), None)),
             Err(err) => Ok(PipelineData::Value(
-                Value::Error {
-                    error: Box::new(err.into()),
-                },
+                Value::error(err.into(), call.head),
                 None,
             )),
         }
@@ -133,16 +126,6 @@ impl Command for Explore {
     }
 }
 
-// For now, this doesn't use StyleComputer.
-// As such, closures can't be given as styles for Explore.
-fn is_need_banner(config: &HashMap<String, Value>) -> Option<bool> {
-    config.get("help_banner").and_then(|v| v.as_bool().ok())
-}
-
-fn is_need_esc_exit(config: &HashMap<String, Value>) -> Option<bool> {
-    config.get("exit_esc").and_then(|v| v.as_bool().ok())
-}
-
 fn update_config(config: &mut HashMap<String, Value>, show_index: bool, show_head: bool) {
     let mut hm = config.get("table").and_then(create_map).unwrap_or_default();
     if show_index {
@@ -184,6 +167,10 @@ fn style_from_config(config: &HashMap<String, Value>) -> StyleConfig {
             style.status_info = *s;
         }
 
+        if let Some(s) = colors.get("success") {
+            style.status_success = *s;
+        }
+
         if let Some(s) = colors.get("warn") {
             style.status_warn = *s;
         }
@@ -210,6 +197,8 @@ fn prepare_default_config(config: &mut HashMap<String, Value>) {
 
     const STATUS_INFO: Style = color(None, None);
 
+    const STATUS_SUCCESS: Style = color(Some(Color::Black), Some(Color::Green));
+
     const STATUS_WARN: Style = color(None, None);
 
     const TABLE_SPLIT_LINE: Style = color(Some(Color::Rgb(64, 64, 64)), None);
@@ -230,8 +219,6 @@ fn prepare_default_config(config: &mut HashMap<String, Value>) {
 
     const TABLE_SELECT_COLUMN: Style = color(None, None);
 
-    const TRY_BORDER_COLOR: Style = color(None, None);
-
     const CONFIG_CURSOR_COLOR: Style = color(Some(Color::Black), Some(Color::LightYellow));
 
     insert_style(config, "status_bar_background", STATUS_BAR);
@@ -247,6 +234,7 @@ fn prepare_default_config(config: &mut HashMap<String, Value>) {
             .unwrap_or_default();
 
         insert_style(&mut hm, "info", STATUS_INFO);
+        insert_style(&mut hm, "success", STATUS_SUCCESS);
         insert_style(&mut hm, "warn", STATUS_WARN);
         insert_style(&mut hm, "error", STATUS_ERROR);
 
@@ -272,17 +260,6 @@ fn prepare_default_config(config: &mut HashMap<String, Value>) {
         config.insert(String::from("table"), map_into_value(hm));
     }
 
-    {
-        let mut hm = config
-            .get("try")
-            .and_then(parse_hash_map)
-            .unwrap_or_default();
-
-        insert_style(&mut hm, "border_color", TRY_BORDER_COLOR);
-
-        config.insert(String::from("try"), map_into_value(hm));
-    }
-
     {
         let mut hm = config
             .get("config")
@@ -296,10 +273,8 @@ fn prepare_default_config(config: &mut HashMap<String, Value>) {
 }
 
 fn parse_hash_map(value: &Value) -> Option<HashMap<String, Value>> {
-    value.as_record().ok().map(|(cols, vals)| {
-        cols.iter()
-            .take(vals.len())
-            .zip(vals)
+    value.as_record().ok().map(|val| {
+        val.iter()
             .map(|(col, val)| (col.clone(), val.clone()))
             .collect::<HashMap<_, _>>()
     })
@@ -356,15 +331,6 @@ fn include_nu_config(config: &mut HashMap<String, Value>, style_computer: &Style
             config.insert(String::from("table"), map_into_value(map));
         }
 
-        {
-            let mut map = config
-                .get("try")
-                .and_then(parse_hash_map)
-                .unwrap_or_default();
-            insert_style(&mut map, "border_color", line_color);
-            config.insert(String::from("try"), map_into_value(map));
-        }
-
         {
             let mut map = config
                 .get("config")
