@@ -17,9 +17,9 @@ pub type CtrlC = Option<Arc<AtomicBool>>;
 
 pub use command::{is_ignored_command, run_command_with_value, run_nu_command};
 pub use lscolor::{create_lscolors, lscolorize};
-pub use string::truncate_str;
+pub use string::{string_width, truncate_str};
 pub use table::try_build_table;
-pub use value::{collect_input, collect_pipeline, create_map, map_into_value, nu_str};
+pub use value::{collect_input, collect_pipeline, create_map, map_into_value};
 
 pub fn has_simple_value(data: &[Vec<Value>]) -> Option<&Value> {
     if data.len() == 1
