@@ -4,11 +4,11 @@ use std::borrow::Cow;
 
 use std::collections::HashMap;
 
-use crossterm::event::{KeyCode, KeyEvent};
+use crossterm::event::{KeyCode, KeyEvent, KeyModifiers};
 use nu_color_config::{get_color_map, StyleComputer};
 use nu_protocol::{
     engine::{EngineState, Stack},
-    Value,
+    Record, Value,
 };
 use ratatui::{layout::Rect, widgets::Block};
 
@@ -246,13 +246,13 @@ impl<'a> RecordView<'a> {
         let covered_percent = report_row_position(layer.cursor);
         let cursor = report_cursor_position(self.mode, layer.cursor);
         let message = layer.name.clone().unwrap_or_default();
+        // note: maybe came up with a better short names? E/V/N?
+        let mode = match self.mode {
+            UIMode::Cursor => String::from("EDIT"),
+            UIMode::View => String::from("VIEW"),
+        };
 
-        Report {
-            message,
-            context: covered_percent,
-            context2: cursor,
-            level: Severity::Info,
-        }
+        Report::new(message, Severity::Info, mode, cursor, covered_percent)
     }
 }
 
@@ -451,6 +451,36 @@ impl<'a> RecordLayer<'a> {
 }
 
 fn handle_key_event_view_mode(view: &mut RecordView, key: &KeyEvent) -> Option<Transition> {
+    match key {
+        KeyEvent {
+            code: KeyCode::Char('u'),
+            modifiers: KeyModifiers::CONTROL,
+            ..
+        }
+        | KeyEvent {
+            code: KeyCode::PageUp,
+            ..
+        } => {
+            view.get_layer_last_mut().cursor.prev_row_page();
+
+            return Some(Transition::Ok);
+        }
+        KeyEvent {
+            code: KeyCode::Char('d'),
+            modifiers: KeyModifiers::CONTROL,
+            ..
+        }
+        | KeyEvent {
+            code: KeyCode::PageDown,
+            ..
+        } => {
+            view.get_layer_last_mut().cursor.next_row_page();
+
+            return Some(Transition::Ok);
+        }
+        _ => {}
+    }
+
     match key.code {
         KeyCode::Esc => {
             if view.layer_stack.len() > 1 {
@@ -473,42 +503,32 @@ fn handle_key_event_view_mode(view: &mut RecordView, key: &KeyEvent) -> Option<T
             Some(Transition::Ok)
         }
         KeyCode::Char('e') => Some(Transition::Cmd(String::from("expand"))),
-        KeyCode::Up => {
+        KeyCode::Up | KeyCode::Char('k') => {
             view.get_layer_last_mut().cursor.prev_row_i();
 
             Some(Transition::Ok)
         }
-        KeyCode::Down => {
+        KeyCode::Down | KeyCode::Char('j') => {
             view.get_layer_last_mut().cursor.next_row_i();
 
             Some(Transition::Ok)
         }
-        KeyCode::Left => {
+        KeyCode::Left | KeyCode::Char('h') => {
             view.get_layer_last_mut().cursor.prev_column_i();
 
             Some(Transition::Ok)
         }
-        KeyCode::Right => {
+        KeyCode::Right | KeyCode::Char('l') => {
             view.get_layer_last_mut().cursor.next_column_i();
 
             Some(Transition::Ok)
         }
-        KeyCode::PageUp => {
-            view.get_layer_last_mut().cursor.prev_row_page();
-
-            Some(Transition::Ok)
-        }
-        KeyCode::PageDown => {
-            view.get_layer_last_mut().cursor.next_row_page();
-
-            Some(Transition::Ok)
-        }
-        KeyCode::Home => {
+        KeyCode::Home | KeyCode::Char('g') => {
             view.get_layer_last_mut().cursor.row_move_to_start();
 
             Some(Transition::Ok)
         }
-        KeyCode::End => {
+        KeyCode::End | KeyCode::Char('G') => {
             view.get_layer_last_mut().cursor.row_move_to_end();
 
             Some(Transition::Ok)
@@ -518,48 +538,68 @@ fn handle_key_event_view_mode(view: &mut RecordView, key: &KeyEvent) -> Option<T
 }
 
 fn handle_key_event_cursor_mode(view: &mut RecordView, key: &KeyEvent) -> Option<Transition> {
+    match key {
+        KeyEvent {
+            code: KeyCode::Char('u'),
+            modifiers: KeyModifiers::CONTROL,
+            ..
+        }
+        | KeyEvent {
+            code: KeyCode::PageUp,
+            ..
+        } => {
+            view.get_layer_last_mut().cursor.prev_row_page();
+
+            return Some(Transition::Ok);
+        }
+        KeyEvent {
+            code: KeyCode::Char('d'),
+            modifiers: KeyModifiers::CONTROL,
+            ..
+        }
+        | KeyEvent {
+            code: KeyCode::PageDown,
+            ..
+        } => {
+            view.get_layer_last_mut().cursor.next_row_page();
+
+            return Some(Transition::Ok);
+        }
+        _ => {}
+    }
+
     match key.code {
         KeyCode::Esc => {
             view.set_view_mode();
 
             Some(Transition::Ok)
         }
-        KeyCode::Up => {
+        KeyCode::Up | KeyCode::Char('k') => {
             view.get_layer_last_mut().cursor.prev_row();
 
             Some(Transition::Ok)
         }
-        KeyCode::Down => {
+        KeyCode::Down | KeyCode::Char('j') => {
             view.get_layer_last_mut().cursor.next_row();
 
             Some(Transition::Ok)
         }
-        KeyCode::Left => {
+        KeyCode::Left | KeyCode::Char('h') => {
             view.get_layer_last_mut().cursor.prev_column();
 
             Some(Transition::Ok)
         }
-        KeyCode::Right => {
+        KeyCode::Right | KeyCode::Char('l') => {
             view.get_layer_last_mut().cursor.next_column();
 
             Some(Transition::Ok)
         }
-        KeyCode::PageUp => {
-            view.get_layer_last_mut().cursor.prev_row_page();
-
-            Some(Transition::Ok)
-        }
-        KeyCode::PageDown => {
-            view.get_layer_last_mut().cursor.next_row_page();
-
-            Some(Transition::Ok)
-        }
-        KeyCode::Home => {
+        KeyCode::Home | KeyCode::Char('g') => {
             view.get_layer_last_mut().cursor.row_move_to_start();
 
             Some(Transition::Ok)
         }
-        KeyCode::End => {
+        KeyCode::End | KeyCode::Char('G') => {
             view.get_layer_last_mut().cursor.row_move_to_end();
 
             Some(Transition::Ok)
@@ -683,17 +723,18 @@ fn build_table_as_list(v: &RecordView) -> Value {
         .records
         .iter()
         .cloned()
-        .map(|vals| Value::Record {
-            cols: headers.clone(),
-            vals,
-            span: NuSpan::unknown(),
+        .map(|vals| {
+            Value::record(
+                Record {
+                    cols: headers.clone(),
+                    vals,
+                },
+                NuSpan::unknown(),
+            )
         })
         .collect();
 
-    Value::List {
-        vals,
-        span: NuSpan::unknown(),
-    }
+    Value::list(vals, NuSpan::unknown())
 }
 
 fn build_table_as_record(v: &RecordView) -> Value {
@@ -702,11 +743,7 @@ fn build_table_as_record(v: &RecordView) -> Value {
     let cols = layer.columns.to_vec();
     let vals = layer.records.get(0).map_or(Vec::new(), |row| row.clone());
 
-    Value::Record {
-        cols,
-        vals,
-        span: NuSpan::unknown(),
-    }
+    Value::record(Record { cols, vals }, NuSpan::unknown())
 }
 
 fn report_cursor_position(mode: UIMode, cursor: XYCursor) -> String {
