@@ -781,6 +781,30 @@ fn test_nothing_comparison_eq() {
         )
     ))
 }
+#[rstest]
+#[case(b"let a = 1 err> /dev/null", "RedirectionInLetMut")]
+#[case(b"let a = 1 out> /dev/null", "RedirectionInLetMut")]
+#[case(b"mut a = 1 err> /dev/null", "RedirectionInLetMut")]
+#[case(b"mut a = 1 out> /dev/null", "RedirectionInLetMut")]
+// This two cases cause AssignInPipeline instead of RedirectionInLetMut
+#[case(b"let a = 1 out+err> /dev/null", "AssignInPipeline")]
+#[case(b"mut a = 1 out+err> /dev/null", "AssignInPipeline")]
+fn test_redirection_with_letmut(#[case] phase: &[u8], #[case] expected: &str) {
+    let engine_state = EngineState::new();
+    let mut working_set = StateWorkingSet::new(&engine_state);
+    let _block = parse(&mut working_set, None, phase, true);
+    match expected {
+        "RedirectionInLetMut" => assert!(matches!(
+            working_set.parse_errors.first(),
+            Some(ParseError::RedirectionInLetMut(_, _))
+        )),
+        "AssignInPipeline" => assert!(matches!(
+            working_set.parse_errors.first(),
+            Some(ParseError::AssignInPipeline(_, _, _, _))
+        )),
+        _ => panic!("unexpected pattern"),
+    }
+}
 
 #[test]
 fn test_nothing_comparison_neq() {
@@ -1007,6 +1031,18 @@ mod string {
     }
 }
 
+#[rstest]
+#[case(b"let a = }")]
+#[case(b"mut a = }")]
+#[case(b"let a = | }")]
+#[case(b"mut a = | }")]
+fn test_semi_open_brace(#[case] phrase: &[u8]) {
+    let engine_state = EngineState::new();
+    let mut working_set = StateWorkingSet::new(&engine_state);
+    // this should not panic
+    let _block = parse(&mut working_set, None, phrase, true);
+}
+
 mod range {
     use super::*;
     use nu_protocol::ast::{RangeInclusion, RangeOperator};
