@@ -3,6 +3,7 @@ mod capture_block;
 mod command;
 mod engine_state;
 mod overlay;
+mod pattern_match;
 mod stack;
 
 pub use call_info::*;
@@ -10,4 +11,5 @@ pub use capture_block::*;
 pub use command::*;
 pub use engine_state::*;
 pub use overlay::*;
+pub use pattern_match::*;
 pub use stack::*;
