@@ -121,7 +121,7 @@ impl Type {
             Type::Block => String::from("block"),
             Type::Closure => String::from("closure"),
             Type::Bool => String::from("bool"),
-            Type::CellPath => String::from("cell path"),
+            Type::CellPath => String::from("cell-path"),
             Type::Date => String::from("date"),
             Type::Duration => String::from("duration"),
             Type::Filesize => String::from("filesize"),
@@ -131,11 +131,11 @@ impl Type {
             Type::Record(_) => String::from("record"),
             Type::Table(_) => String::from("table"),
             Type::List(_) => String::from("list"),
-            Type::MatchPattern => String::from("match pattern"),
+            Type::MatchPattern => String::from("match-pattern"),
             Type::Nothing => String::from("nothing"),
             Type::Number => String::from("number"),
             Type::String => String::from("string"),
-            Type::ListStream => String::from("list stream"),
+            Type::ListStream => String::from("list-stream"),
             Type::Any => String::from("any"),
             Type::Error => String::from("error"),
             Type::Binary => String::from("binary"),
@@ -151,7 +151,7 @@ impl Display for Type {
             Type::Block => write!(f, "block"),
             Type::Closure => write!(f, "closure"),
             Type::Bool => write!(f, "bool"),
-            Type::CellPath => write!(f, "cell path"),
+            Type::CellPath => write!(f, "cell-path"),
             Type::Date => write!(f, "date"),
             Type::Duration => write!(f, "duration"),
             Type::Filesize => write!(f, "filesize"),
@@ -192,13 +192,13 @@ impl Display for Type {
             Type::Nothing => write!(f, "nothing"),
             Type::Number => write!(f, "number"),
             Type::String => write!(f, "string"),
-            Type::ListStream => write!(f, "list stream"),
+            Type::ListStream => write!(f, "list-stream"),
             Type::Any => write!(f, "any"),
             Type::Error => write!(f, "error"),
             Type::Binary => write!(f, "binary"),
             Type::Custom(custom) => write!(f, "{custom}"),
             Type::Signature => write!(f, "signature"),
-            Type::MatchPattern => write!(f, "match pattern"),
+            Type::MatchPattern => write!(f, "match-pattern"),
         }
     }
 }
