@@ -4,8 +4,7 @@ use std::str::FromStr;
 
 use crate::ast::{CellPath, MatchPattern, PathMember};
 use crate::engine::{Block, Closure};
-use crate::ShellError;
-use crate::{Range, Spanned, Value};
+use crate::{Range, Record, ShellError, Spanned, Value};
 use chrono::{DateTime, FixedOffset};
 
 pub trait FromValue: Sized {
@@ -20,24 +19,16 @@ impl FromValue for Value {
 
 impl FromValue for Spanned<i64> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Int { val, span } => Ok(Spanned {
-                item: *val,
-                span: *span,
-            }),
-            Value::Filesize { val, span } => Ok(Spanned {
-                item: *val,
-                span: *span,
-            }),
-            Value::Duration { val, span } => Ok(Spanned {
-                item: *val,
-                span: *span,
-            }),
+            Value::Int { val, .. } => Ok(Spanned { item: *val, span }),
+            Value::Filesize { val, .. } => Ok(Spanned { item: *val, span }),
+            Value::Duration { val, .. } => Ok(Spanned { item: *val, span }),
 
             v => Err(ShellError::CantConvert {
                 to_type: "integer".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -54,7 +45,7 @@ impl FromValue for i64 {
             v => Err(ShellError::CantConvert {
                 to_type: "integer".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -63,20 +54,18 @@ impl FromValue for i64 {
 
 impl FromValue for Spanned<f64> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Int { val, span } => Ok(Spanned {
+            Value::Int { val, .. } => Ok(Spanned {
                 item: *val as f64,
-                span: *span,
-            }),
-            Value::Float { val, span } => Ok(Spanned {
-                item: *val,
-                span: *span,
+                span,
             }),
+            Value::Float { val, .. } => Ok(Spanned { item: *val, span }),
 
             v => Err(ShellError::CantConvert {
                 to_type: "float".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -91,7 +80,7 @@ impl FromValue for f64 {
             v => Err(ShellError::CantConvert {
                 to_type: "float".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -100,34 +89,35 @@ impl FromValue for f64 {
 
 impl FromValue for Spanned<usize> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Int { val, span } => {
+            Value::Int { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(Spanned {
                         item: *val as usize,
-                        span: *span,
+                        span,
                     })
                 }
             }
-            Value::Filesize { val, span } => {
+            Value::Filesize { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(Spanned {
                         item: *val as usize,
-                        span: *span,
+                        span,
                     })
                 }
             }
-            Value::Duration { val, span } => {
+            Value::Duration { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(Spanned {
                         item: *val as usize,
-                        span: *span,
+                        span,
                     })
                 }
             }
@@ -135,7 +125,7 @@ impl FromValue for Spanned<usize> {
             v => Err(ShellError::CantConvert {
                 to_type: "non-negative integer".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -144,24 +134,25 @@ impl FromValue for Spanned<usize> {
 
 impl FromValue for usize {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Int { val, span } => {
+            Value::Int { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(*val as usize)
                 }
             }
-            Value::Filesize { val, span } => {
+            Value::Filesize { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(*val as usize)
                 }
             }
-            Value::Duration { val, span } => {
+            Value::Duration { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(*val as usize)
                 }
@@ -170,7 +161,7 @@ impl FromValue for usize {
             v => Err(ShellError::CantConvert {
                 to_type: "non-negative integer".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -186,7 +177,7 @@ impl FromValue for String {
             v => Err(ShellError::CantConvert {
                 to_type: "string".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -203,12 +194,12 @@ impl FromValue for Spanned<String> {
                     return Err(ShellError::CantConvert {
                         to_type: "string".into(),
                         from_type: v.get_type().to_string(),
-                        span: v.span()?,
+                        span: v.span(),
                         help: None,
                     })
                 }
             },
-            span: v.span()?,
+            span: v.span(),
         })
     }
 }
@@ -224,7 +215,7 @@ impl FromValue for Vec<String> {
                     c => Err(ShellError::CantConvert {
                         to_type: "string".into(),
                         from_type: c.get_type().to_string(),
-                        span: c.span()?,
+                        span: c.span(),
                         help: None,
                     }),
                 })
@@ -232,7 +223,7 @@ impl FromValue for Vec<String> {
             v => Err(ShellError::CantConvert {
                 to_type: "string".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -245,23 +236,26 @@ impl FromValue for Vec<Spanned<String>> {
         match v {
             Value::List { vals, .. } => vals
                 .iter()
-                .map(|val| match val {
-                    Value::String { val, span } => Ok(Spanned {
-                        item: val.clone(),
-                        span: *span,
-                    }),
-                    c => Err(ShellError::CantConvert {
-                        to_type: "string".into(),
-                        from_type: c.get_type().to_string(),
-                        span: c.span()?,
-                        help: None,
-                    }),
+                .map(|val| {
+                    let val_span = val.span();
+                    match val {
+                        Value::String { val, .. } => Ok(Spanned {
+                            item: val.clone(),
+                            span: val_span,
+                        }),
+                        c => Err(ShellError::CantConvert {
+                            to_type: "string".into(),
+                            from_type: c.get_type().to_string(),
+                            span: c.span(),
+                            help: None,
+                        }),
+                    }
                 })
                 .collect::<Result<Vec<Spanned<String>>, ShellError>>(),
             v => Err(ShellError::CantConvert {
                 to_type: "string".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -278,7 +272,7 @@ impl FromValue for Vec<bool> {
                     c => Err(ShellError::CantConvert {
                         to_type: "bool".into(),
                         from_type: c.get_type().to_string(),
-                        span: c.span()?,
+                        span: c.span(),
                         help: None,
                     }),
                 })
@@ -286,7 +280,7 @@ impl FromValue for Vec<bool> {
             v => Err(ShellError::CantConvert {
                 to_type: "bool".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -295,7 +289,7 @@ impl FromValue for Vec<bool> {
 
 impl FromValue for CellPath {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
-        let span = v.span()?;
+        let span = v.span();
         match v {
             Value::CellPath { val, .. } => Ok(val.clone()),
             Value::String { val, .. } => Ok(CellPath {
@@ -305,14 +299,14 @@ impl FromValue for CellPath {
                     optional: false,
                 }],
             }),
-            Value::Int { val, span } => {
+            Value::Int { val, .. } => {
                 if val.is_negative() {
-                    Err(ShellError::NeedsPositiveValue(*span))
+                    Err(ShellError::NeedsPositiveValue(span))
                 } else {
                     Ok(CellPath {
                         members: vec![PathMember::Int {
                             val: *val as usize,
-                            span: *span,
+                            span,
                             optional: false,
                         }],
                     })
@@ -335,7 +329,7 @@ impl FromValue for bool {
             v => Err(ShellError::CantConvert {
                 to_type: "bool".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -344,15 +338,13 @@ impl FromValue for bool {
 
 impl FromValue for Spanned<bool> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Bool { val, span } => Ok(Spanned {
-                item: *val,
-                span: *span,
-            }),
+            Value::Bool { val, .. } => Ok(Spanned { item: *val, span }),
             v => Err(ShellError::CantConvert {
                 to_type: "bool".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -366,7 +358,7 @@ impl FromValue for DateTime<FixedOffset> {
             v => Err(ShellError::CantConvert {
                 to_type: "date".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -375,15 +367,13 @@ impl FromValue for DateTime<FixedOffset> {
 
 impl FromValue for Spanned<DateTime<FixedOffset>> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Date { val, span } => Ok(Spanned {
-                item: *val,
-                span: *span,
-            }),
+            Value::Date { val, .. } => Ok(Spanned { item: *val, span }),
             v => Err(ShellError::CantConvert {
                 to_type: "date".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -397,7 +387,7 @@ impl FromValue for Range {
             v => Err(ShellError::CantConvert {
                 to_type: "range".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -406,15 +396,16 @@ impl FromValue for Range {
 
 impl FromValue for Spanned<Range> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Range { val, span } => Ok(Spanned {
+            Value::Range { val, .. } => Ok(Spanned {
                 item: (**val).clone(),
-                span: *span,
+                span,
             }),
             v => Err(ShellError::CantConvert {
                 to_type: "range".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -429,7 +420,7 @@ impl FromValue for Vec<u8> {
             v => Err(ShellError::CantConvert {
                 to_type: "binary data".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -438,19 +429,20 @@ impl FromValue for Vec<u8> {
 
 impl FromValue for Spanned<Vec<u8>> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Binary { val, span } => Ok(Spanned {
+            Value::Binary { val, .. } => Ok(Spanned {
                 item: val.clone(),
-                span: *span,
+                span,
             }),
-            Value::String { val, span } => Ok(Spanned {
+            Value::String { val, .. } => Ok(Spanned {
                 item: val.bytes().collect(),
-                span: *span,
+                span,
             }),
             v => Err(ShellError::CantConvert {
                 to_type: "binary data".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -459,16 +451,17 @@ impl FromValue for Spanned<Vec<u8>> {
 
 impl FromValue for Spanned<PathBuf> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::String { val, span } => Ok(Spanned {
+            Value::String { val, .. } => Ok(Spanned {
                 item: PathBuf::from_str(val)
-                    .map_err(|err| ShellError::FileNotFoundCustom(err.to_string(), *span))?,
-                span: *span,
+                    .map_err(|err| ShellError::FileNotFoundCustom(err.to_string(), span))?,
+                span,
             }),
             v => Err(ShellError::CantConvert {
                 to_type: "range".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -483,22 +476,21 @@ impl FromValue for Vec<Value> {
             v => Err(ShellError::CantConvert {
                 to_type: "Vector of values".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
     }
 }
 
-// A record
-impl FromValue for (Vec<String>, Vec<Value>) {
+impl FromValue for Record {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
         match v {
-            Value::Record { cols, vals, .. } => Ok((cols.clone(), vals.clone())),
+            Value::Record { val, .. } => Ok(val.clone()),
             v => Err(ShellError::CantConvert {
                 to_type: "Record".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -519,7 +511,7 @@ impl FromValue for Closure {
             v => Err(ShellError::CantConvert {
                 to_type: "Closure".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -533,7 +525,7 @@ impl FromValue for Block {
             v => Err(ShellError::CantConvert {
                 to_type: "Block".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -542,22 +534,19 @@ impl FromValue for Block {
 
 impl FromValue for Spanned<Closure> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::Closure {
-                val,
-                captures,
-                span,
-            } => Ok(Spanned {
+            Value::Closure { val, captures, .. } => Ok(Spanned {
                 item: Closure {
                     block_id: *val,
                     captures: captures.clone(),
                 },
-                span: *span,
+                span,
             }),
             v => Err(ShellError::CantConvert {
                 to_type: "Closure".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -566,15 +555,16 @@ impl FromValue for Spanned<Closure> {
 
 impl FromValue for Spanned<MatchPattern> {
     fn from_value(v: &Value) -> Result<Self, ShellError> {
+        let span = v.span();
         match v {
-            Value::MatchPattern { val, span } => Ok(Spanned {
+            Value::MatchPattern { val, .. } => Ok(Spanned {
                 item: *val.clone(),
-                span: *span,
+                span,
             }),
             v => Err(ShellError::CantConvert {
                 to_type: "Match pattern".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
@@ -588,7 +578,7 @@ impl FromValue for MatchPattern {
             v => Err(ShellError::CantConvert {
                 to_type: "Match pattern".into(),
                 from_type: v.get_type().to_string(),
-                span: v.span()?,
+                span: v.span(),
                 help: None,
             }),
         }
