@@ -1,7 +1,8 @@
-use crate::table_theme::TableTheme;
+use crate::{convert_style, table_theme::TableTheme};
 use nu_ansi_term::Style;
 use nu_color_config::TextStyle;
 use nu_protocol::TrimStrategy;
+use nu_utils::strip_ansi_unlikely;
 use std::cmp::min;
 use std::collections::HashMap;
 use tabled::{
@@ -141,6 +142,10 @@ impl NuTable {
         self.indent = (left, right);
     }
 
+    pub fn get_records_mut(&mut self) -> &mut NuRecords {
+        &mut self.data
+    }
+
     /// Converts a table to a String.
     ///
     /// It returns None in case where table cannot be fit to a terminal width.
@@ -270,6 +275,8 @@ fn set_border_head(table: &mut Table, with_footer: bool, wctrl: TableWidthCtrl)
         table.with(
             Settings::default()
                 .with(wctrl)
+                .with(StripColorFromRow(0))
+                .with(StripColorFromRow(count_rows - 1))
                 .with(HeaderMove((0, 0), true))
                 .with(HeaderMove((count_rows - 1 - 1, count_rows - 1), false)),
         );
@@ -277,6 +284,7 @@ fn set_border_head(table: &mut Table, with_footer: bool, wctrl: TableWidthCtrl)
         table.with(
             Settings::default()
                 .with(wctrl)
+                .with(StripColorFromRow(0))
                 .with(HeaderMove((0, 0), true)),
         );
     }
@@ -708,10 +716,6 @@ impl<R, D> TableOption<R, D, ColoredConfig> for SetAlignment {
     }
 }
 
-fn convert_style(style: Style) -> Color {
-    Color::new(style.prefix().to_string(), style.suffix().to_string())
-}
-
 struct SetDimensions(Vec<usize>);
 
 impl<R> TableOption<R, CompleteDimensionVecRecords<'_>, ColoredConfig> for SetDimensions {
@@ -908,3 +912,18 @@ fn remove_row(recs: &mut NuRecords, row: usize) -> Vec<String> {
 
     columns
 }
+
+struct StripColorFromRow(usize);
+
+impl TableOption<NuRecords, CompleteDimensionVecRecords<'_>, ColoredConfig> for StripColorFromRow {
+    fn change(
+        self,
+        recs: &mut NuRecords,
+        _: &mut ColoredConfig,
+        _: &mut CompleteDimensionVecRecords<'_>,
+    ) {
+        for cell in &mut recs[self.0] {
+            *cell = CellInfo::new(strip_ansi_unlikely(cell.as_ref()).into_owned());
+        }
+    }
+}
