@@ -3,7 +3,7 @@ use std::collections::HashMap;
 
 use nu_color_config::{Alignment, StyleComputer, TextStyle};
 use nu_engine::column::get_columns;
-use nu_protocol::{ast::PathMember, Config, ShellError, Span, TableIndexMode, Value};
+use nu_protocol::{ast::PathMember, Config, Record, ShellError, Span, TableIndexMode, Value};
 use tabled::grid::config::Position;
 
 use crate::{
@@ -35,8 +35,8 @@ impl ExpandedTable {
         expanded_table_entry2(item, Cfg { opts, format: self })
     }
 
-    pub fn build_map(self, cols: &[String], vals: &[Value], opts: TableOpts<'_>) -> StringResult {
-        expanded_table_kv(cols, vals, Cfg { opts, format: self })
+    pub fn build_map(self, record: &Record, opts: TableOpts<'_>) -> StringResult {
+        expanded_table_kv(record, Cfg { opts, format: self })
     }
 
     pub fn build_list(self, vals: &[Value], opts: TableOpts<'_>) -> StringResult {
@@ -110,7 +110,7 @@ fn expanded_table_list(input: &[Value], cfg: Cfg<'_>) -> TableResult {
                 return Ok(None);
             }
 
-            if let Value::Error { error } = item {
+            if let Value::Error { error, .. } = item {
                 return Err(*error.clone());
             }
 
@@ -150,7 +150,7 @@ fn expanded_table_list(input: &[Value], cfg: Cfg<'_>) -> TableResult {
                 return Ok(None);
             }
 
-            if let Value::Error { error } = item {
+            if let Value::Error { error, .. } = item {
                 return Err(*error.clone());
             }
 
@@ -238,7 +238,7 @@ fn expanded_table_list(input: &[Value], cfg: Cfg<'_>) -> TableResult {
                 return Ok(None);
             }
 
-            if let Value::Error { error } = item {
+            if let Value::Error { error, .. } = item {
                 return Err(*error.clone());
             }
 
@@ -340,9 +340,14 @@ fn expanded_table_list(input: &[Value], cfg: Cfg<'_>) -> TableResult {
     Ok(Some(TableOutput::new(table, true, with_index)))
 }
 
-fn expanded_table_kv(cols: &[String], vals: &[Value], cfg: Cfg<'_>) -> StringResult {
+fn expanded_table_kv(record: &Record, cfg: Cfg<'_>) -> StringResult {
     let theme = load_theme_from_config(cfg.opts.config);
-    let key_width = cols.iter().map(|col| string_width(col)).max().unwrap_or(0);
+    let key_width = record
+        .cols
+        .iter()
+        .map(|col| string_width(col))
+        .max()
+        .unwrap_or(0);
     let count_borders =
         theme.has_inner() as usize + theme.has_right() as usize + theme.has_left() as usize;
     let padding = 2;
@@ -352,8 +357,8 @@ fn expanded_table_kv(cols: &[String], vals: &[Value], cfg: Cfg<'_>) -> StringRes
 
     let value_width = cfg.opts.width - key_width - count_borders - padding - padding;
 
-    let mut data = Vec::with_capacity(cols.len());
-    for (key, value) in cols.iter().zip(vals) {
+    let mut data = Vec::with_capacity(record.len());
+    for (key, value) in record {
         if nu_utils::ctrl_c::was_pressed(&cfg.opts.ctrlc) {
             return Ok(None);
         }
@@ -398,9 +403,10 @@ fn expand_table_value(
         return Ok(Some((value_to_string_clean(value, cfg), false)));
     }
 
+    let span = value.span();
     match value {
-        Value::List { vals, span } => {
-            let mut inner_cfg = dive_options(cfg, *span);
+        Value::List { vals, .. } => {
+            let mut inner_cfg = dive_options(cfg, span);
             inner_cfg.opts.width = value_width;
             let table = expanded_table_list(vals, inner_cfg)?;
 
@@ -422,8 +428,8 @@ fn expand_table_value(
                 }
             }
         }
-        Value::Record { cols, vals, span } => {
-            if cols.is_empty() {
+        Value::Record { val: record, .. } => {
+            if record.is_empty() {
                 // Like list case return styled string instead of empty value
                 return Ok(Some((
                     value_to_wrapped_string(value, cfg, value_width),
@@ -431,9 +437,9 @@ fn expand_table_value(
                 )));
             }
 
-            let mut inner_cfg = dive_options(cfg, *span);
+            let mut inner_cfg = dive_options(cfg, span);
             inner_cfg.opts.width = value_width;
-            let result = expanded_table_kv(cols, vals, inner_cfg)?;
+            let result = expanded_table_kv(record, inner_cfg)?;
             match result {
                 Some(result) => Ok(Some((result, true))),
                 None => Ok(Some((
@@ -479,22 +485,23 @@ fn expanded_table_entry2(item: &Value, cfg: Cfg<'_>) -> NuText {
         return nu_value_to_string_clean(item, cfg.opts.config, cfg.opts.style_computer);
     }
 
+    let span = item.span();
     match &item {
-        Value::Record { cols, vals, span } => {
-            if cols.is_empty() && vals.is_empty() {
+        Value::Record { val: record, .. } => {
+            if record.is_empty() {
                 return nu_value_to_string(item, cfg.opts.config, cfg.opts.style_computer);
             }
 
             // we verify what is the structure of a Record cause it might represent
-            let inner_cfg = dive_options(&cfg, *span);
-            let table = expanded_table_kv(cols, vals, inner_cfg);
+            let inner_cfg = dive_options(&cfg, span);
+            let table = expanded_table_kv(record, inner_cfg);
 
             match table {
                 Ok(Some(table)) => (table, TextStyle::default()),
                 _ => nu_value_to_string(item, cfg.opts.config, cfg.opts.style_computer),
             }
         }
-        Value::List { vals, span } => {
+        Value::List { vals, .. } => {
             if cfg.format.flatten && is_simple_list(vals) {
                 return value_list_to_string(
                     vals,
@@ -504,7 +511,7 @@ fn expanded_table_entry2(item: &Value, cfg: Cfg<'_>) -> NuText {
                 );
             }
 
-            let inner_cfg = dive_options(&cfg, *span);
+            let inner_cfg = dive_options(&cfg, span);
             let table = expanded_table_list(vals, inner_cfg);
 
             let out = match table {
