@@ -2,12 +2,12 @@ use ical::parser::vcard::component::*;
 use ical::property::Property;
 use indexmap::map::IndexMap;
 use nu_plugin::{EvaluatedCall, LabeledError};
-use nu_protocol::{PluginExample, ShellError, Span, Spanned, Value};
+use nu_protocol::{record, PluginExample, Record, ShellError, Span, Value};
 
 pub const CMD_NAME: &str = "from vcf";
 
 pub fn from_vcf_call(call: &EvaluatedCall, input: &Value) -> Result<Value, LabeledError> {
-    let span = input.span().unwrap_or(call.head);
+    let span = input.span();
     let input_string = input.as_string()?;
     let head = call.head;
 
@@ -23,21 +23,19 @@ pub fn from_vcf_call(call: &EvaluatedCall, input: &Value) -> Result<Value, Label
 
     let iter = parser.map(move |contact| match contact {
         Ok(c) => contact_to_value(c, head),
-        Err(e) => Value::Error {
-            error: Box::new(ShellError::UnsupportedInput(
+        Err(e) => Value::error(
+            ShellError::UnsupportedInput(
                 format!("input cannot be parsed as .vcf ({e})"),
                 "value originates from here".into(),
                 head,
                 span,
-            )),
-        },
+            ),
+            span,
+        ),
     });
 
     let collected: Vec<_> = iter.collect();
-    Ok(Value::List {
-        vals: collected,
-        span: head,
-    })
+    Ok(Value::list(collected, head))
 }
 
 pub fn examples() -> Vec<PluginExample> {
@@ -49,12 +47,12 @@ EMAIL:foo@bar.com
 END:VCARD' | from vcf"
             .into(),
         description: "Converts ics formatted string to table".into(),
-        result: Some(Value::List {
-            vals: vec![Value::Record {
+        result: Some(Value::list(
+            vec![Value::test_record(Record {
                 cols: vec!["properties".to_string()],
-                vals: vec![Value::List {
-                    vals: vec![
-                        Value::Record {
+                vals: vec![Value::list(
+                    vec![
+                        Value::test_record(Record {
                             cols: vec![
                                 "name".to_string(),
                                 "value".to_string(),
@@ -63,13 +61,10 @@ END:VCARD' | from vcf"
                             vals: vec![
                                 Value::test_string("N"),
                                 Value::test_string("Foo"),
-                                Value::Nothing {
-                                    span: Span::test_data(),
-                                },
+                                Value::nothing(Span::test_data()),
                             ],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec![
                                 "name".to_string(),
                                 "value".to_string(),
@@ -78,13 +73,10 @@ END:VCARD' | from vcf"
                             vals: vec![
                                 Value::test_string("FN"),
                                 Value::test_string("Bar"),
-                                Value::Nothing {
-                                    span: Span::test_data(),
-                                },
+                                Value::nothing(Span::test_data()),
                             ],
-                            span: Span::test_data(),
-                        },
-                        Value::Record {
+                        }),
+                        Value::test_record(Record {
                             cols: vec![
                                 "name".to_string(),
                                 "value".to_string(),
@@ -93,59 +85,52 @@ END:VCARD' | from vcf"
                             vals: vec![
                                 Value::test_string("EMAIL"),
                                 Value::test_string("foo@bar.com"),
-                                Value::Nothing {
-                                    span: Span::test_data(),
-                                },
+                                Value::nothing(Span::test_data()),
                             ],
-                            span: Span::test_data(),
-                        },
+                        }),
                     ],
-                    span: Span::test_data(),
-                }],
-                span: Span::test_data(),
-            }],
-            span: Span::test_data(),
-        }),
+                    Span::test_data(),
+                )],
+            })],
+            Span::test_data(),
+        )),
     }]
 }
 
 fn contact_to_value(contact: VcardContact, span: Span) -> Value {
-    let mut row = IndexMap::new();
-    row.insert(
-        "properties".to_string(),
-        properties_to_value(contact.properties, span),
-    );
-    Value::from(Spanned { item: row, span })
+    Value::record(
+        record! { "properties" => properties_to_value(contact.properties, span) },
+        span,
+    )
 }
 
 fn properties_to_value(properties: Vec<Property>, span: Span) -> Value {
-    Value::List {
-        vals: properties
+    Value::list(
+        properties
             .into_iter()
             .map(|prop| {
-                let mut row = IndexMap::new();
-
-                let name = Value::String {
-                    val: prop.name,
-                    span,
-                };
+                let name = Value::string(prop.name, span);
                 let value = match prop.value {
-                    Some(val) => Value::String { val, span },
-                    None => Value::Nothing { span },
+                    Some(val) => Value::string(val, span),
+                    None => Value::nothing(span),
                 };
                 let params = match prop.params {
                     Some(param_list) => params_to_value(param_list, span),
-                    None => Value::Nothing { span },
+                    None => Value::nothing(span),
                 };
 
-                row.insert("name".to_string(), name);
-                row.insert("value".to_string(), value);
-                row.insert("params".to_string(), params);
-                Value::from(Spanned { item: row, span })
+                Value::record(
+                    record! {
+                        "name" => name,
+                        "value" => value,
+                        "params" => params,
+                    },
+                    span,
+                )
             })
             .collect::<Vec<Value>>(),
         span,
-    }
+    )
 }
 
 fn params_to_value(params: Vec<(String, Vec<String>)>, span: Span) -> Value {
@@ -156,9 +141,9 @@ fn params_to_value(params: Vec<(String, Vec<String>)>, span: Span) -> Value {
             .into_iter()
             .map(|val| Value::string(val, span))
             .collect();
-        let values = Value::List { vals: values, span };
+        let values = Value::list(values, span);
         row.insert(param_name, values);
     }
 
-    Value::from(Spanned { item: row, span })
+    Value::record(row.into_iter().collect(), span)
 }
