@@ -1,5 +1,6 @@
 use nu_test_support::nu;
 use pretty_assertions::assert_eq;
+use rstest::rstest;
 
 const MODULE_SETUP: &str = r#"
     module spam {
@@ -107,13 +108,78 @@ fn const_nothing() {
     assert_eq!(actual.out, "nothing");
 }
 
+#[rstest]
+#[case(&["const x = not false", "$x"], "true")]
+#[case(&["const x = false", "const y = not $x", "$y"], "true")]
+#[case(&["const x = not false", "const y = not $x", "$y"], "false")]
+fn const_unary_operator(#[case] inp: &[&str], #[case] expect: &str) {
+    let actual = nu!(&inp.join("; "));
+    assert_eq!(actual.out, expect);
+}
+
+#[rstest]
+#[case(&["const x = 1 + 2", "$x"], "3")]
+#[case(&["const x = 1 * 2", "$x"], "2")]
+#[case(&["const x = 4 / 2", "$x"], "2")]
+#[case(&["const x = 4 mod 3", "$x"], "1")]
+#[case(&["const x = 5.0 / 2.0", "$x"], "2.5")]
+#[case(&[r#"const x = "a" + "b" "#, "$x"], "ab")]
+#[case(&[r#"const x = "a" ++ "b" "#, "$x"], "ab")]
+#[case(&[r#"const x = [1,2] ++ [3]"#, "$x | describe"], "list<int>")]
+#[case(&[r#"const x = 0x[1,2] ++ 0x[3]"#, "$x | describe"], "binary")]
+#[case(&[r#"const x = 0x[1,2] ++ [3]"#, "$x | describe"], "list<any>")]
+#[case(&["const x = 1 < 2", "$x"], "true")]
+#[case(&["const x = (3 * 200) > (2 * 100)", "$x"], "true")]
+#[case(&["const x = (3 * 200) < (2 * 100)", "$x"], "false")]
+#[case(&["const x = (3 * 200) == (2 * 300)", "$x"], "true")]
+fn const_binary_operator(#[case] inp: &[&str], #[case] expect: &str) {
+    let actual = nu!(&inp.join("; "));
+    assert_eq!(actual.out, expect);
+}
+
+#[rstest]
+#[case(&["const x = 1 / 0", "$x"], "division by zero")]
+#[case(&["const x = 10 ** 10000000", "$x"], "pow operation overflowed")]
+#[case(&["const x = 2 ** 62 * 2", "$x"], "multiply operation overflowed")]
+#[case(&["const x = 1 ++ 0", "$x"], "doesn't support this value")]
+fn const_operator_error(#[case] inp: &[&str], #[case] expect: &str) {
+    let actual = nu!(&inp.join("; "));
+    assert!(actual.err.contains(expect));
+}
+
+#[rstest]
+#[case(&["const x = (1..3)", "$x | math sum"], "6")]
+#[case(&["const x = (1..3)", "$x | describe"], "range")]
+fn const_range(#[case] inp: &[&str], #[case] expect: &str) {
+    let actual = nu!(&inp.join("; "));
+    assert_eq!(actual.out, expect);
+}
+
 #[test]
-fn const_unsupported() {
-    let inp = &["const x = ('abc' | str length)"];
+fn const_subexpression_supported() {
+    let inp = &["const x = ('spam')", "$x"];
 
     let actual = nu!(&inp.join("; "));
 
-    assert!(actual.err.contains("not_a_constant"));
+    assert_eq!(actual.out, "spam");
+}
+
+#[test]
+fn const_command_supported() {
+    let inp = &["const x = ('spam' | str length)", "$x"];
+
+    let actual = nu!(&inp.join("; "));
+
+    assert_eq!(actual.out, "4");
+}
+
+#[test]
+fn const_command_unsupported() {
+    let inp = &["const x = (loop { break })"];
+
+    let actual = nu!(&inp.join("; "));
+
+    assert!(actual.err.contains("not_a_const_command"));
 }
 
 #[test]
@@ -125,6 +191,12 @@ fn const_in_scope() {
     assert_eq!(actual.out, "x");
 }
 
+#[test]
+fn not_a_const_help() {
+    let actual = nu!("const x = ('abc' | str length -h)");
+    assert!(actual.err.contains("not_a_const_help"));
+}
+
 #[test]
 fn complex_const_export() {
     let inp = &[MODULE_SETUP, "use spam", "$spam.X"];
@@ -250,3 +322,35 @@ fn complex_const_overlay_use_hide() {
     let actual = nu!(&inp.join("; "));
     assert!(actual.err.contains("nu::parser::variable_not_found"));
 }
+
+// const implementations of commands without dedicated tests
+#[test]
+fn describe_const() {
+    let actual = nu!("const x = ('abc' | describe); $x");
+    assert_eq!(actual.out, "string");
+}
+
+#[test]
+fn ignore_const() {
+    let actual = nu!(r#"const x = ("spam" | ignore); $x == null"#);
+    assert_eq!(actual.out, "true");
+}
+
+#[test]
+fn version_const() {
+    let actual = nu!("const x = (version); $x");
+    assert!(actual.err.is_empty());
+}
+
+#[test]
+fn if_const() {
+    let actual = nu!("const x = (if 2 < 3 { 'yes!' }); $x");
+    assert_eq!(actual.out, "yes!");
+
+    let actual = nu!("const x = (if 5 < 3 { 'yes!' } else { 'no!' }); $x");
+    assert_eq!(actual.out, "no!");
+
+    let actual =
+        nu!("const x = (if 5 < 3 { 'yes!' } else if 4 < 5 { 'no!' } else { 'okay!' }); $x");
+    assert_eq!(actual.out, "no!");
+}
